//Copyright (c) 2004 Aaron Sullivan. All rights reserved.
#ifndef RANDOMNUM_H
#define RANDOMNUM_H

#include "SDL.h"
//RNG (Random Number Generator)
//Uses RANROT Method
//modified from source found at iDevGames tutorial on Random Number Generation

//To use:
//RNG random;
//random.init()
//cout << random.generate() << " is a random floating point number.\n";
//cout << random.generate(50,100) << " is a random number between 50 and 100.\n";

//to seed using something besides SDL_GetTicks()
//random.init(MethodToGetSeedNumber);

//to remove SDL dependency completely:
//1. remove #include "SDL.h"
//2. remove the entire init function that has no parameters: "void init(void)"
//3. use the second init function only: "void init(unsigned int seed)" as described above.

class RNG
{
public:

    void init(void)
    {
	unsigned int seed = SDL_GetTicks();
	m_low = seed;
	m_high = ~seed;
    }

    void init(unsigned int seed)
    {
	m_low = seed;
	m_high = ~seed;
    }

    unsigned int generate()
    {
	m_high = (m_high<<16) + (m_high>>16);
	m_high += m_low;
	m_low += m_high;
	return m_high;
    }

    unsigned int generate(Uint32 min, Uint32 max)
    {
	//if min and max are switched... switch them back
	if (min > max)
	{
	    unsigned int temp;
	    temp = max;
	    max = min;
	    min = temp;
	}
	
	return generate()%(max - min+1) + min;
    }

private:
    int m_high;
    int m_low;
};

#endif