//Copyright (c) 2004 Aaron Sullivan. All rights reserved.
#include "sb_Destroyer.h"

sb_Destroyer::sb_Destroyer()
{
	reset();
}

void sb_Destroyer::reset()
{
	x = 0.0f;
	y = 0.0f;
	targetX = x;
	targetY = y;
	dx = 0;
	dy = 0;
	r = 1.0f;
	g = 0.0f;
	b = 0.1f;
	a = 0.6f;
	rotation = 0.0f;
	targetRotation = rotation;
	collisionCircle.init(x,y,16.0f);
	active = false;
	directionOfAdvance.dx = -1.0f;
	directionOfAdvance.dy = -1.0f;
	currentCommand = kDC_wait;
	commandCompleted = true;
	commandStarted = false;
	movementSpeed = 0.05f;
	rotationSpeed = 0.2f;
	moving = false;
	rotating = false;
	delay = 0;
	delayTimeRemaining = delay;
	delaying = false;
	wait = 1000;
	waitTimeRemaining = wait;
	waiting = false;
}

void sb_Destroyer::changeType( float newMovementSpeed, float newRotationSpeed, Uint32 newDelay )
{
	movementSpeed = newMovementSpeed;
	rotationSpeed = newRotationSpeed;
	delay = newDelay;
}

//determine all vectors and rotations needed for movement
//relative to a vector using numbers -1 or 0 or 1 that points in direction of frontline
void sb_Destroyer::setDirectionOfAdvance( sb_vector vectorForForwardMovement )
{
	directionOfAdvance = vectorForForwardMovement;
	
	directionOfRetreat.dx = -directionOfAdvance.dx;
	directionOfRetreat.dy = -directionOfAdvance.dy;
	
	directionOfLeft.dx = directionOfAdvance.dy;
	directionOfLeft.dy = -directionOfAdvance.dx;
	
	directionOfRight.dx = -directionOfAdvance.dy;
	directionOfRight.dy = directionOfAdvance.dx;
	
	if (directionOfAdvance.dx == 1.0f && directionOfAdvance.dy == 0.0f)
	{
		rotationOfAdvance = 0.0f;
		rotationOfRight = 90.0f;
		rotationOfRetreat = 180.0f;
		rotationOfLeft = 270.0f;
	}
	else if (directionOfAdvance.dx == 1.0f && directionOfAdvance.dy == 1.0f)
	{
		rotationOfAdvance = 45.0f;
		rotationOfRight = 135.0f;
		rotationOfRetreat = 225.0f;
		rotationOfLeft = 315.0f;
	}
	else if (directionOfAdvance.dx == 0.0f && directionOfAdvance.dy == 1.0f)
	{
		rotationOfAdvance = 90.0f;
		rotationOfRight = 180.0f;
		rotationOfRetreat = 270.0f;
		rotationOfLeft = 0.0f;
	}
	else if (directionOfAdvance.dx == -1.0f && directionOfAdvance.dy == 1.0f)
	{
		rotationOfAdvance = 135.0f;
		rotationOfRight = 225.0f;
		rotationOfRetreat = 315.0f;
		rotationOfLeft = 45.0f;
	}
	else if (directionOfAdvance.dx == -1.0f && directionOfAdvance.dy == 0.0f)
	{
		rotationOfAdvance = 180.0f;
		rotationOfRight = 270.0f;
		rotationOfRetreat = 0.0f;
		rotationOfLeft = 90.0f;
	}
	else if (directionOfAdvance.dx == -1.0f && directionOfAdvance.dy == -1.0f)
	{
		rotationOfAdvance = 225.0f;
		rotationOfRight = 315.0f;
		rotationOfRetreat = 45.0f;
		rotationOfLeft = 135.0f;
	}
	else if (directionOfAdvance.dx == 0.0f && directionOfAdvance.dy == -1.0f)
	{
		rotationOfAdvance = 270.0f;
		rotationOfRight = 0.0f;
		rotationOfRetreat = 90.0f;
		rotationOfLeft = 180.0f;	
	}
	else if (directionOfAdvance.dx == 1.0f && directionOfAdvance.dy == -1.0f)
	{
		rotationOfAdvance = 315.0f;
		rotationOfRight = 45.0f;
		rotationOfRetreat = 135.0f;
		rotationOfLeft = 225.0f;
	}
	
}

void sb_Destroyer::makeActive()
{
	active = true;
}

void sb_Destroyer::makeInactive()
{
	active = false;
}

int sb_Destroyer::isActive()
{
	return active;
}

void sb_Destroyer::animate( Uint32 ticksPassed )
{
	if (active && commandCompleted == false) //don't even animate if not active or there is no new command
	{
		//this assumes that these actions will always happen in order: rotate, move, delay
		//this means it will always finish the cycle (i.e. can't JUST rotate without moving and delaying)
		//it can start at moving or delaying, however
		if (rotating)
		{
			if (rotateTowardsTarget( rotationSpeed * ticksPassed ))
			{
				rotating = false;
				moving = true;
				delaying = false;
			}
		}
		
		if (moving)
		{
			if (moveTowardsTarget( ticksPassed ))
			{
				moving = false;
				delaying = true;
			}
		}
		
		if (delaying)
		{
			delayTimeRemaining -= ticksPassed;
			if (delayTimeRemaining <= 0)
			{
				delayTimeRemaining = 0;
				delaying = false;
				commandCompleted = true;
				commandStarted = false;
				return;
			}
		}
		
		if (waiting)
		{
			waitTimeRemaining -= ticksPassed;
			if (waitTimeRemaining <= 0)
			{
				waitTimeRemaining = 0;
				waiting = false;
				delaying = true; //after we wait (for wait command, shoot, or explode) we delay
				return;
			}
		}
	}
}

void sb_Destroyer::draw()
{
	//vertex points in the outline of the sb_Destroyer
	float thePoints[] = {
		-16,0,
		-12, 4,
		-12, 8,
		-8, 8,
		-8, 12,
		-16, 12,
		-12, 16,
		-2, 16,
		4, 6,
		8, 6, 
		8, 16,
		16, 8, 
		16, -8,
		8, -16, 
		8, -6,
		4, -6,
		-2, -16,
		-12, -16,
		-16, -12,
		-8, -12,
		-8, -8,
		-12, -8,
		-12, -4,
		-16,0,
		-2000, -2000
	};
	
	glAAFlush();
	glLoadIdentity();
	glTranslatef( x, y, 0.0f );
	glRotatef( rotation, 0.0f, 0.0f, 1.0f );
	glAAColor4f(r,g,b,a);
	glAALineWidth(2.0f);
	
	glAABegin(GL_LINE_STRIP);
	int i;
	i = 0;
	while ( thePoints[i] != -2000 )
	{
		glAAVertex2f( thePoints[i], thePoints[i+1] );
		i += 2;
	}
	glAAEnd();
}


void sb_Destroyer::doCommand( sb_DestroyerCommand command )
{
	currentCommand = command;
	commandCompleted = false; //there is a new command now, and it's not complete
	commandStarted = false; //it doesn't start until we hit the animate function
	
	//every command is initiated differently
	switch(currentCommand)
	{
		case kDC_wait:
			waitTimeRemaining = wait;
			delayTimeRemaining = delay; //set enough delay for the wait and the pause inbetween commands
			rotating = false;
			moving = false;
			delaying = false;
			waiting = true;
			commandStarted = true;
			break;
			
		case kDC_advance:
			dx = directionOfAdvance.dx * movementSpeed;
			dy = directionOfAdvance.dy * movementSpeed;
			targetX = x + directionOfAdvance.dx * 32.0f; //the target is 16 pixels away (dx is between 0 and 1 )
			targetY = y + directionOfAdvance.dy * 32.0f; //the 16 comes from the shieldGrid... should be connected to the actual grid not a hack like this
			targetRotation = rotationOfAdvance;
			
			if (rotation != targetRotation) //if it isn't already facing the right way
			{
				rotating = true; //start it rotating
				moving = false;
				delaying = false;
			}
			else
			{
				//otherwise, we just move
				rotating = false;
				moving = true;
				delaying = false;
			}
			
			delayTimeRemaining = delay;
			commandStarted = true;
			break;
		case kDC_retreat:
			dx = directionOfRetreat.dx * movementSpeed;
			dy = directionOfRetreat.dy * movementSpeed;
			targetX = x + directionOfRetreat.dx * 32.0f;
			targetY = y + directionOfRetreat.dy * 32.0f; 
			targetRotation = rotationOfRetreat;
			
			if (rotation != targetRotation)
			{
				rotating = true;
				moving = false;
				delaying = false;
			}
			else
			{
				rotating = false;
				moving = true;
				delaying = false;
			}
			
			delayTimeRemaining = delay;
			commandStarted = true;
			break;
		case kDC_flankLeft:
			dx = directionOfLeft.dx * movementSpeed;
			dy = directionOfLeft.dy * movementSpeed;
			targetX = x + directionOfLeft.dx * 32.0f;
			targetY = y + directionOfLeft.dy * 32.0f;
			targetRotation = rotationOfLeft;
			
			if (rotation != targetRotation)
			{
				rotating = true;
				moving = false;
				delaying = false;
			}
			else
			{
				rotating = false;
				moving = true;
				delaying = false;
			}
			
			delayTimeRemaining = delay;
			commandStarted = true;
			break;
		case kDC_flankRight:
			dx = directionOfRight.dx * movementSpeed;
			dy = directionOfRight.dy * movementSpeed;
			targetX = x + directionOfRight.dx * 32.0f;
			targetY = y + directionOfRight.dy * 32.0f; 
			targetRotation = rotationOfRight;
			
			if (rotation != targetRotation)
			{
				rotating = true;
				moving = false;
				delaying = false;
			}
				else
				{
					rotating = false;
					moving = true;
					delaying = false;
				}
				
				delayTimeRemaining = delay;
			commandStarted = true;
			break;
		case kDC_reverse:
			dx = directionOfRetreat.dx * movementSpeed;
			dy = directionOfRetreat.dy * movementSpeed;
			targetX = x + directionOfRetreat.dx * 32.0f; 
			targetY = y + directionOfRetreat.dy * 32.0f; 
			targetRotation = rotationOfAdvance; //this is the primary difference of reverse and retreat
			
			if (rotation != targetRotation)
			{
				rotating = true;
				moving = false;
				delaying = false;
			}
				else
				{
					rotating = false;
					moving = true;
					delaying = false;
				}
				
				delayTimeRemaining = delay;
			commandStarted = true;
			break;
		case kDC_shootAtShields:
			//actual shooting of a missile is taken care of by sb_DestroyerControl
			waitTimeRemaining = wait;
			delayTimeRemaining = delay; //set enough delay for the wait and the pause inbetween commands
			rotating = false;
			moving = false;
			delaying = false;
			waiting = true;
			commandStarted = true;
			break;
		case kDC_explode:
			waitTimeRemaining = wait;
			delayTimeRemaining = delay; //set enough delay for the wait and the pause inbetween commands
			rotating = false;
			moving = false;
			delaying = false;
			waiting = true;
			commandStarted = true;
			a = CLAMP(a-0.2f, 0.0f, 1.0f); //make more transparent for verification (quick hack)
			reset();
			active = false; //make the ship inactive
			break;
	}
}

int sb_Destroyer::readyForNewCommand()
{
	return commandCompleted;
}

int sb_Destroyer::intersects( sb_Circle otherCircle )
{
	return collisionCircle.isInContactWith( otherCircle );
}

int sb_Destroyer::intersects( float dotX, float dotY )
{
	return collisionCircle.isInContactWith( dotX, dotY );
}

//int sb_Destroyer::intersects( int gridX, int gridY )

sb_Circle sb_Destroyer::destinationCircle()
{
	sb_Circle destinationCircle;
	destinationCircle.init(targetX, targetY, collisionCircle.getRadius());
	return destinationCircle;
}

void sb_Destroyer::moveTo(float newX, float newY)
{
	x = newX;
	y = newY;
	collisionCircle.moveTo(x, y);
}

int sb_Destroyer::moveTowardsTarget( Uint32 ticksPassed )
{
	//increase x and y by dx and dy (dx and dy are set in animate() )
	x += dx * ticksPassed;
	y += dy * ticksPassed;
	//don't let x or y move beyond target
	if (dx < 0 && x < targetX) x = targetX;
	if (dx > 0 && x > targetX) x = targetX;
	if (dy < 0 && y < targetY) y = targetY;
	if (dy > 0 && y > targetY) y = targetY;
	
	collisionCircle.moveTo(x, y);
	
	if (x == targetX && y == targetY)
	{
		return true;
	}
	return false;
}

void sb_Destroyer::setRotation(float degrees)
{
	rotation = degrees;
}

void sb_Destroyer::setRotationTowardsTarget()
{
	rotation = rotationOfAdvance;
}

void sb_Destroyer::rotate(float degrees)
{
	float tempRotation;
	tempRotation = rotation + degrees;
	if (tempRotation >= 360.0f)
	{
		rotation = tempRotation - 360;
	}
	else if (tempRotation < 0.0f)
	{
		rotation = 360 + tempRotation;
	}
	else
	{
		rotation = tempRotation;
	}
}

int sb_Destroyer::rotateTowardsTarget( float degrees )
{
	float halfway;
	
	if (rotation > targetRotation - 1.0 && rotation < targetRotation + 1.0)
	{
		rotation = targetRotation;
		return true;
	}
	else
	{
		if (rotation < 180)
		{
			halfway = rotation + 180;
			if (targetRotation > rotation && targetRotation < halfway)
			{
				//go clockwise
				rotate( degrees );
			}
			else
			{
				//go counter-clockwise
				rotate( -degrees );
			}
		}
		else if (rotation >= 180)
		{
			halfway = rotation - 180;
			if (targetRotation < rotation && targetRotation > halfway)
			{
				//go counter-clockwise
				rotate( -degrees );
			}
			else
			{
				//go clockwise
				rotate( degrees );
			}
		}
	}
	return false;
}

void sb_Destroyer::setColor(float red, float green, float blue, float alpha)
{
	r = CLAMP(red, 0.0f, 1.0f);
	g = CLAMP(green, 0.0f, 1.0f);
	b = CLAMP(blue, 0.0f, 1.0f);
	a = CLAMP(alpha, 0.0f, 1.0f);
}

float sb_Destroyer::getX()
{
	return x;
}

float sb_Destroyer::getY()
{
	return y;
}

float sb_Destroyer::getRotation()
{
	return rotation;
}

sb_Circle sb_Destroyer::getCollisionCircle()
{
	return collisionCircle;
}

sb_Circle sb_Destroyer::getDestinationCircleWithCommand( sb_DestroyerCommand command)
{
	float tX, tY;
	float tempRadius = collisionCircle.getRadius();
	
	sb_Circle tempDestCircle;
	
	switch(command)
	{
		case kDC_advance:
			tX = x + directionOfAdvance.dx * 32.0f; //the t is 16 pixels away (dx is between 0 and 1 )
			tY = y + directionOfAdvance.dy * 32.0f; //the 16 comes from the shieldGrid... should be connected to the actual grid not a hack like this
			break;
		case kDC_retreat:
			tX = x + directionOfRetreat.dx * 32.0f;
			tY = y + directionOfRetreat.dy * 32.0f; 
			break;
		case kDC_flankLeft:
			tX = x + directionOfLeft.dx * 32.0f;
			tY = y + directionOfLeft.dy * 32.0f;
			break;
		case kDC_flankRight:
			tX = x + directionOfRight.dx * 32.0f;
			tY = y + directionOfRight.dy * 32.0f;
			break;
		case kDC_reverse:
			tX = x + directionOfRetreat.dx * 32.0f; 
			tY = y + directionOfRetreat.dy * 32.0f; 
			break;
		case kDC_wait:
		case kDC_shootAtShields:
		case kDC_explode:
			tX = x;
			tY = y;
		break;
	}
	tempDestCircle.init(tX,tY,tempRadius);
	return tempDestCircle;
}
