//Copyright (c) 2004 Aaron Sullivan. All rights reserved.
#ifndef SB_DESTROYER_H
#define SB_DESTROYER_H

#include "sb_global.h"

enum sb_DestroyerCommand
{
	kDC_wait = 0,
	kDC_advance,
	kDC_retreat,
	kDC_flankLeft,
	kDC_flankRight,
	kDC_reverse,
	kDC_shootAtShields,
	kDC_explode
};

class sb_Destroyer
{
public:
	sb_Destroyer();
	//void init( sb_ShieldGridPtr relatedShieldGrid );
	void reset();
	void changeType( float newMovementSpeed, float newRotationSpeed, Uint32 newDelay );
	void setDirectionOfAdvance( sb_vector vectorForForwardMovement );
	void makeActive();
	void makeInactive();
	int isActive();
	
	void animate( Uint32 ticksPassed );
	void draw();
	
	void doCommand( sb_DestroyerCommand command );
	int readyForNewCommand();
	int intersects( sb_Circle otherCircle );
	int intersects( float dotX, float dotY );
	//int intersects( int gridX, int gridY );
	sb_Circle destinationCircle();
	
	void moveTo( float newX, float newY );
	int moveTowardsTarget( Uint32 ticksPassed );
	void setRotation( float degrees );
	void setRotationTowardsTarget();
	void rotate( float degrees );
	int rotateTowardsTarget( float degrees );
	void setColor( float red, float green, float blue, float alpha );
	
	float getX();
	float getY();
	float getRotation();
	sb_Circle getCollisionCircle();
	sb_Circle getDestinationCircleWithCommand( sb_DestroyerCommand command);
		
private:
	float x, y;
	float targetX, targetY;
	float dx, dy; //when moving, this is the change in x and y
	float r, g, b, a;
	float rotation;
	float targetRotation;
	sb_Circle collisionCircle;
	//sb_ShieldGridPtr pGrid; //pointer to shieldGrid so we can interact with it
	
	int active;
	
	sb_vector directionOfAdvance;
	sb_vector directionOfRetreat;
	sb_vector directionOfLeft;
	sb_vector directionOfRight;
	float rotationOfAdvance;
	float rotationOfRetreat;
	float rotationOfLeft;
	float rotationOfRight;
	
	sb_DestroyerCommand currentCommand;
	int commandStarted;
	int commandCompleted;
	float movementSpeed;
	float rotationSpeed;
	
	int moving;
	int rotating;
	int delaying;
	int waiting;
	
	Sint32 delay; //for delay between movements
	Sint32 delayTimeRemaining;
	Sint32 wait;
	Sint32 waitTimeRemaining;
};

#endif