//Copyright (c) 2004 Aaron Sullivan. All rights reserved.
#include "sb_DestroyerControl.h"

sb_DestroyerControl::sb_DestroyerControl()
{
	rng.init(SDL_GetTicks());
	reset();
}

void sb_DestroyerControl::reset()
{
	int i;
	
	for (i=0; i<totalDestroyers; i++)
	{
		d[i].reset();
	}
	
	enterBorder.begin.x = 0.0f;
	enterBorder.begin.y = 0.0f;
	enterBorder.end.x = 10.0f;
	enterBorder.end.y = 0.0f;
	
	advanceVector.dx = 1.0f;
	advanceVector.dy = 0.0f;
	
	currentDestroyer = 0;
	stopped = true;
	stopping = false;
	
	missiles.reset();
	missiles.setColor(1.0f,0.0f,0.1f,0.3f);
}

void sb_DestroyerControl::init( sb_line newEntranceBorder, sb_vector newAdvanceVector, sb_ShieldGridPtr newGrid )
{
	//the border line can't be diagonal or this just won't work
	int i;
	float tempx, tempy;
	enterBorder = newEntranceBorder;
	
	if (enterBorder.begin.x > enterBorder.end.x)
	{
		tempx = enterBorder.begin.x;
		enterBorder.begin.x = enterBorder.end.x;
		enterBorder.end.x = tempx;
	}
	if (enterBorder.begin.y > enterBorder.end.y)
	{
		tempy = enterBorder.begin.y;
		enterBorder.begin.y = enterBorder.end.y;
		enterBorder.end.y = tempy;
	}
	
	advanceVector = newAdvanceVector;
	grid = newGrid;
	
	for (i=0; i<totalDestroyers; i++)
	{
		d[i].setDirectionOfAdvance(advanceVector);
	}
}

//returns number not launched
int sb_DestroyerControl::launch( int numberToLaunch )
{
	int unlaunchedCount;
	int i, availableIndex;
	int tries;
	int rx, ry;
	float lx, ly;
	int dAvailable = destroyersAvailable();
	if (numberToLaunch > dAvailable)
	{
		unlaunchedCount = numberToLaunch - dAvailable;
		numberToLaunch = dAvailable;
	}

	availableIndex = 0;
	for (i=0; i < numberToLaunch; i++)
	{
		tries = 0;
		while (d[availableIndex].isActive()) { availableIndex++;} //move to next available destroyer
		do
		{
			tries++;
			rx = rng.generate((int)enterBorder.begin.x, (int)enterBorder.end.x);
			ry = rng.generate((int)enterBorder.begin.y, (int)enterBorder.end.y);
			lx = (rx / 32) * 32.0f + 16.0f; //make sure point is at right interval on shieldGrid ***should be using pointer to grid
			ly = (ry / 32) * 32.0f + 16.0f;
			d[availableIndex].moveTo(lx, ly);
		} while (collidesWithOthers(availableIndex) && tries <= 500); //tries are counted because it's possible there are no spots left or random just doesn't guess the right spots
		if (tries > 500)
		{
			unlaunchedCount++;
		}
		else
		{
			d[availableIndex].makeActive();
			d[availableIndex].setDirectionOfAdvance( advanceVector );
			d[availableIndex].setRotationTowardsTarget();
			
		}
		availableIndex++;
	}
	return unlaunchedCount;
}

void sb_DestroyerControl::animate( Uint32 ticksPassed )
{	
	if (stopped) return;
	int i, k;
	int targetSectionX, targetSectionY;
	
	for (i=0; i<totalDestroyers; i++)
	{
		if (d[i].isActive())
		{
			//if a destroyer goes off the edge of the screen eliminate it
			if (d[i].getX() > grid->getXRes() - grid->getSectorSize() ||
				d[i].getX() < grid->getSectorSize() ||
				d[i].getY() > grid->getYRes() - grid->getSectorSize() ||
				d[i].getY() < grid->getSectorSize())
			{
				d[i].makeInactive();
				continue;
			}
			//choose new commands for those that are ready
			if (d[i].readyForNewCommand() && !stopping)
			{
				int randomCommand;
				randomCommand = rng.generate(0,15);
				if(randomCommand > 6 && randomCommand <= 11)
				{
					randomCommand = (int)kDC_advance;
				}
				else if(randomCommand > 11)
				{
					randomCommand = (int)kDC_shootAtShields;
				}
				
				//test for collisions if the command involves movement
				if (randomCommand == (int)kDC_advance ||
					randomCommand == (int)kDC_retreat ||
					randomCommand == (int)kDC_reverse ||
					randomCommand == (int)kDC_flankLeft ||
					randomCommand == (int)kDC_flankRight)
				{
					for (k=0; k<totalDestroyers; k++)
					{
						if (k == i) continue;
						sb_Circle commandDestinationCircle = d[i].getDestinationCircleWithCommand((sb_DestroyerCommand)randomCommand);
						//if two are headed to the same spot or we are going out of bounds we stay still and maybe shoot
						if (d[k].isActive() && 
							(commandDestinationCircle.isInContactWith(d[k].destinationCircle()) ||
							 commandDestinationCircle.getX() > grid->getXRes() - grid->getSectorSize() ||
							 commandDestinationCircle.getX() < grid->getSectorSize() ||
							 commandDestinationCircle.getY() > grid->getYRes() - grid->getSectorSize() ||
							 commandDestinationCircle.getY() < grid->getSectorSize())) 
						{
							randomCommand = (int)kDC_wait;
						}
					}
				} 
				
				//if shooting
				if (randomCommand == (int)kDC_shootAtShields)
				{
					//choose section to shoot at
					targetSectionX = 0;
					targetSectionY = 0;
					int sectionToStopAt = rng.generate(0,50);
					int shieldsFound = false;
					for (k=0; k<sectionToStopAt; k++)
					{
						do
						{
							targetSectionX+=1;
							if(targetSectionX > grid->getXSectors())
							{
								targetSectionX = 0;
								targetSectionY+=1;
								if (targetSectionY > grid->getYSectors())
								{
									if (shieldsFound == false)
									{
										randomCommand = (int)kDC_wait;
										break;
									}
									targetSectionY = 0;
								}
							}
						}while( grid->getSectorValue(targetSectionX, targetSectionY) != kST_shield );
						
						if (grid->getSectorValue(targetSectionX, targetSectionY) == kST_shield)
						{
							shieldsFound = true;
						}
						else
						{
							randomCommand = (int)kDC_wait;
							break;
						}
					}
					//now that section is selected launch it
					if (shieldsFound == true)
						missiles.launch(d[i].getX(), d[i].getY(), d[i].getRotation(), targetSectionX * 16.0f + 8.0f, targetSectionY * 16.0f + 8.0f, 0);
				}
				//set the command in motion for the destroyer
				d[i].doCommand( (sb_DestroyerCommand)randomCommand );
			}
			d[i].animate( ticksPassed );
		}
	}//go to next destroyer to animate
	
	missiles.animate( ticksPassed );
	
	//check to see if any missiles hit the shields
	targetSectionX = 0;
	targetSectionY = 0;
	do
	{
		if ( grid->getSectorValue(targetSectionX, targetSectionY) == kST_shield )
		{
			if (missiles.anyCollisionWith(targetSectionX * 16.0f + 8.0f, targetSectionY * 16.0f + 8.0f))
			{
				//shield has been hit! remove it.
				grid->setSector(targetSectionX, targetSectionY, kST_vacant);
			}
		}
		targetSectionX +=1;
		if (targetSectionX > grid->getXSectors())
		{
			targetSectionX = 0;
			targetSectionY +=1;
		}
		
	} while (targetSectionY <= grid->getYSectors());

	//come to a stop if called for
	if (stopping)
	{
		stopping = false;
		stopped = true; // stay this way if the following tests fail
		for(i=0; i<totalDestroyers; i++)
		{
			if (d[i].isActive() && d[i].readyForNewCommand() == false) //if the active destoyers are still finishing their commands
			{
				stopping = true;
				stopped = false;
				break;
			}
		}
		if (missiles.allInactive() == false) //if there are still some active missiles
		{
			stopping = true;
			stopped = false;
		}
	}
}

void sb_DestroyerControl::draw()
{
	int i;
	for(i=0; i<totalDestroyers; i++)
	{
		if (d[i].isActive())
		{
			d[i].draw();
		}
	}
	missiles.draw();
}

void sb_DestroyerControl::go()
{
	stopping = false;
	stopped = false;
}

void sb_DestroyerControl::stop()
{
	//begin stopping process (no new commands) finishes in animate()
	stopping = true;
	stopped = false;
}

int sb_DestroyerControl::isStopped()
{
	return stopped;
}

sb_Circle sb_DestroyerControl::getNextCollisionCircle(int &destroyerId)
{
	while(d[currentDestroyer].isActive() == false && currentDestroyer < totalDestroyers)
	{
		currentDestroyer++;
	}
	if (currentDestroyer >= totalDestroyers)
	{
		currentDestroyer = 0;
		destroyerId = -1;
		sb_Circle nullCircle;
		nullCircle.init(0.0f,0.0f,0.0f);
		return nullCircle;
	}
	destroyerId = currentDestroyer;
	currentDestroyer++;
	return d[destroyerId].getCollisionCircle();
}

void sb_DestroyerControl::damage(int destroyerId)
{
	if (destroyerId < 0 || destroyerId >= totalDestroyers)
	{
		return;
	}
	else
	{
		d[destroyerId].doCommand( kDC_explode );
	}
}

int sb_DestroyerControl::allInactive()
{
	int i;
	for(i=0; i<totalDestroyers; i++)
	{
		if (d[i].isActive()) return false;
	}
	return true;
}

int sb_DestroyerControl::destroyersAvailable()
{
	int i;
	int totalAvailable = 0;
	for (i=0; i < totalDestroyers; i++)
	{
		if (!d[i].isActive())
		{
			totalAvailable++;
		}
	}
	return totalAvailable;
}

int sb_DestroyerControl::collidesWithOthers( int indexOfDestroyer )
{
	int i;
	for ( i=0; i < totalDestroyers; i++ )
	{
		if (i == indexOfDestroyer) continue;
		if (d[i].intersects(d[indexOfDestroyer].getCollisionCircle()))
		{
			return true;
		}
	}
	return false;
}