//Copyright (c) 2004 Aaron Sullivan. All rights reserved.
#include "sb_GameUtilities.h"

sb_GameUtilities::sb_GameUtilities()
{
	game = NULL;
}

void sb_GameUtilities::init( sb_GamePtr gamePtr )
{
	game = gamePtr;
}

void sb_GameUtilities::testForEnclosures()
{
	int bi, bx, by; //barge index;
	game->totalEnclosures = 0; //build up number of enclosures from zero
	for (bi = 0; bi < game->totalBarges; bi++)
	{
		bx = (int)game->barge[bi].getX() / game->grid.getSectorSize();
		by = (int)game->barge[bi].getY() / game->grid.getSectorSize();
		
		clearSectorTouchedGrid();
		if (canGetToOutsideFrom(bx, by))
		{
			clearSectorTouchedGrid();
			deactivateToOutside(bx, by);
		}
		else
		{
			clearSectorTouchedGrid();
			activateToOutside(bx,by);
			game->totalEnclosures++;
		}
	}
	
	for (bi = 0; bi < game->totalBarges; bi++ )
	{
		bx = (int)game->barge[bi].getX() / game->grid.getSectorSize();
		by = (int)game->barge[bi].getY() / game->grid.getSectorSize();
		if (game->grid.getSectorValue(bx,by) == kST_inactiveObject)
		{
			game->barge[bi].makeInactive();
		}
		else if (game->grid.getSectorValue(bx,by) == kST_activeObject)
		{
			game->barge[bi].makeActive();
		}
	}
	
	for (bi = 0; bi < game->totalGuns; bi++ )
	{
		bx = (int)game->gun[bi].getX() / game->grid.getSectorSize();
		by = (int)game->gun[bi].getY() / game->grid.getSectorSize();
		if (game->grid.getSectorValue(bx,by) == kST_inactiveObject)
		{
			game->gun[bi].makeInactive();
		}
		else if (game->grid.getSectorValue(bx,by) == kST_activeObject)
		{
			game->gun[bi].makeActive();
		}
	}
}

void sb_GameUtilities::clearSectorTouchedGrid()
{
	int ix, iy;
	for (iy=0; iy < 48; iy++)
	{
		for (ix=0; ix < 64; ix++)
		{
			sectorTouched[ix][iy] = false;
		}
	}
}

int sb_GameUtilities::canGetToOutsideFrom( int gridX, int gridY )
{
	if (gridX < 0 || gridX > game->grid.getXSectors() ||
		gridY < 0 || gridY > game->grid.getYSectors() )
	{
		return true;
	}
	
	if (sectorTouched[gridX][gridY]) return false; //don't retest sectors we have already checked
	
	if (game->grid.getSectorValue(gridX,gridY) == kST_outOfRange)
	{
		return true;
	}
	if (game->grid.getSectorValue(gridX,gridY) == kST_shield)
	{
		return false;
	}
	//since this is a valid square keep track that we checked it and continue testing
	sectorTouched[gridX][gridY] = true;
	if (canGetToOutsideFrom(gridX, gridY-1) ||
		canGetToOutsideFrom(gridX+1, gridY-1) ||
		canGetToOutsideFrom(gridX+1, gridY) ||
		canGetToOutsideFrom(gridX+1, gridY+1) ||
		canGetToOutsideFrom(gridX, gridY+1) ||
		canGetToOutsideFrom(gridX-1, gridY+1) ||
		canGetToOutsideFrom(gridX-1, gridY) ||
		canGetToOutsideFrom(gridX-1, gridY-1))
	{
		return true;
	}
	else
	{
		return false;
	}
	
}

void sb_GameUtilities::deactivateToOutside( int gridX, int gridY )
{
	if (gridX < 0 || gridX > game->grid.getXSectors() ||
		gridY < 0 || gridY > game->grid.getYSectors() )
	{
		return;
	}
	
	if (sectorTouched[gridX][gridY]) return false; //don't retest sectors we have already checked
	
	sb_SectorType thisSectorType = game->grid.getSectorValue(gridX,gridY);
	if (thisSectorType == kST_outOfRange)
	{
		return;
	}
	if (thisSectorType == kST_shield)
	{
		return;
	}
	
	//if we get here we are on a section that might have to be changed
	if (thisSectorType == kST_activeObject)
	{
		game->grid.setSector(gridX, gridY, kST_inactiveObject);
	}
	if (thisSectorType == kST_insideShield)
	{
		game->grid.setSector(gridX, gridY, kST_vacant );
	}
	//since this is a valid square continue testing
	sectorTouched[gridX][gridY] = true;
	deactivateToOutside(gridX, gridY-1);
	deactivateToOutside(gridX+1, gridY-1);
	deactivateToOutside(gridX+1, gridY);
	deactivateToOutside(gridX+1, gridY+1);
	deactivateToOutside(gridX, gridY+1);
	deactivateToOutside(gridX-1, gridY+1);
	deactivateToOutside(gridX-1, gridY);
	deactivateToOutside(gridX-1, gridY-1);
}

void sb_GameUtilities::activateToOutside( int gridX, int gridY )
{
	if (gridX < 0 || gridX > game->grid.getXSectors() ||
		gridY < 0 || gridY > game->grid.getYSectors() )
	{
		return;
	}
	
	if (sectorTouched[gridX][gridY]) return false; //don't retest sectors we have already checked
	
	sb_SectorType thisSectorType = game->grid.getSectorValue(gridX,gridY);
	if (thisSectorType == kST_outOfRange)
	{
		return;
	}
	if (thisSectorType == kST_shield)
	{
		return;
	}
	
	//if we get here we are on a section that might have to be changed
	if (thisSectorType == kST_inactiveObject)
	{
		game->grid.setSector(gridX, gridY, kST_activeObject);
	}
	if (thisSectorType == kST_vacant)
	{
		game->grid.setSector(gridX, gridY, kST_insideShield );
	}
	//since this is a valid square continue testing
	sectorTouched[gridX][gridY] = true;
	activateToOutside(gridX, gridY-1);
	activateToOutside(gridX+1, gridY-1);
	activateToOutside(gridX+1, gridY);
	activateToOutside(gridX+1, gridY+1);
	activateToOutside(gridX, gridY+1);
	activateToOutside(gridX-1, gridY+1);
	activateToOutside(gridX-1, gridY);
	activateToOutside(gridX-1, gridY-1);
}