//Copyright (c) 2004 Aaron Sullivan. All rights reserved.
#include "sb_Gun.h"

sb_Gun::sb_Gun()
{
	x = 0;
	y = 0;
	r = 1.0f;
	g = 1.0f;
	b = 0.0f;
	a = 0.6f;
	rotation = 0.0f;
	active = false;
	reloading = false;
	inGame = false;
	reloadTimeRemaining = 3000;
	scale = 3.0f;
}

void sb_Gun::init(sb_ShieldGridPtr relatedShieldGrid)
{
	pGrid = relatedShieldGrid;
}

void sb_Gun::animate( Uint32 ticks )
{
	if (!reloading && active)
	{
		rotate((float)(0.1*ticks));
	}
	else if (active)
	{
		reloadTimeRemaining -= ticks;
		if (reloadTimeRemaining <= 0)
		{
			reloadTimeRemaining = 0;
			reloading = false;
		}
	}
}

void sb_Gun::draw()
{	
	//vertex points in the outline of the sb_Gun
	float thePoints[] = {
		-0.3, -1.7,
		-0.3, -2.5,
		-1.5, -2.5,
		-2.5, -1.5,
		-2.5, -0.3,
		-1.7, -0.3,
		-1.7, 0.3,
		-2.5, 0.3,
		-2.5, 1.5,
		-1.5, 2.5,
		-0.3, 2.5,
		-0.3, 1.7,
		0.3, 1.7,
		0.3, 2.5,
		1.5, 2.5,
		2.5, 1.5,
		2.5, 0.3,
		1.7, 0.3,
		1.7, -0.3,
		2.5, -0.3,
		2.5, -1.5,
		1.5, -2.5,
		0.3, -2.5,
		0.3, -1.7,
		-0.3, -1.7,
		-2000, -2000
	};
	
	glAAFlush();
	glLoadIdentity();
	glTranslatef( x, y, 0.0f );
	glRotatef( rotation, 0.0f, 0.0f, 1.0f );
	
	if (active) glAAColor4f(r,g,b,a);
	else glAAColor4f(r,g,CLAMP(b+0.4f, 0.0, 1.0f),CLAMP(a-0.2f, 0.1f, 1.0f));
	
	glAALineWidth(2.0f);
	
	glAABegin(GL_LINE_STRIP);
	int i;
	i = 0;
	while ( thePoints[i] != -2000 )
	{
		glAAVertex2f( thePoints[i]*scale, thePoints[i+1]*scale );
		i += 2;
	}
	glAAEnd();
	
}



void sb_Gun::drawSquareInGrid()
{
	sb_point cornerSector;
	cornerSector = pGrid->sectorPointOnDot((int)(x - pGrid->getSectorSize()*0.5), (int)(y - pGrid->getSectorSize()*0.5));
	float sX, sY;
	float sX2, sY2;
	sX = cornerSector.x * pGrid->getSectorSize();
	sY = cornerSector.y * pGrid->getSectorSize();
	sX2 = sX + pGrid->getSectorSize()*2;
	sY2 = sY + pGrid->getSectorSize()*2;
	glAAFlush();
	glLoadIdentity();
	//make it more gray and more transparent than gun color
	glAAColor4f(CLAMP(r-0.2f,0.1f,1.0f),CLAMP(g-0.2f,0.1f,1.0f),CLAMP(b-0.2f,0.1f,1.0f),CLAMP(a-0.2f,0.3f,1.0f));
	glAALineWidth(3.0f);
	glAABegin(GL_LINE_STRIP);
	glAAVertex2f(sX, sY);
	glAAVertex2f(sX2, sY);
	glAAVertex2f(sX2, sY2);
	glAAVertex2f(sX, sY2);
	glAAVertex2f(sX, sY);
	glAAEnd();
}

void sb_Gun::moveTo(float newX, float newY)
{
	x = newX;
	y = newY;
}

void sb_Gun::setRotation(float degrees)
{
	rotation = degrees;
}

void sb_Gun::rotate(float degrees)
{
	float tempRotation;
	tempRotation = rotation + degrees;
	if (tempRotation >= 360.0f)
	{
		rotation = tempRotation - 360;
	}
	else if (tempRotation <= 0.0f)
	{
		rotation = 360 + tempRotation;
	}
	else
	{
		rotation = tempRotation;
	}
}

void sb_Gun::setColor(float red, float green, float blue, float alpha)
{
	r = CLAMP(red, 0.0f, 1.0f);
	g = CLAMP(green, 0.0f, 1.0f);
	b = CLAMP(blue, 0.0f, 1.0f);
	a = CLAMP(alpha, 0.0f, 1.0f);
}

int sb_Gun::isActive()
{
	return active;
}

int sb_Gun::isReloading()
{
	return reloading;
}

void sb_Gun::makeInactive()
{
	active = false;
}

void sb_Gun::makeActive()
{
	active = true;
}

float sb_Gun::getRotation()
{
	return rotation;
}

void sb_Gun::reload()
{
	reloading = true;
	reloadTimeRemaining = 3000;
}

/* fitIntoGrid()
important: this can fail (return false) Where a barge can go is heavily
restricted so it should always be tested to make sure it
made it in.
*/
int sb_Gun::fitIntoGrid()
{
	sb_point cornerSector;
	cornerSector = pGrid->sectorPointOnDot((int)(x - pGrid->getSectorSize()*0.5), (int)(y - pGrid->getSectorSize()*0.5));
	if (cornerSector.x == -1) //if the point is not in the grid
	{
		return false; //we can't fit it in the grid so return false
	}
	//Now we need to test for other reasons it can't fit
	//if it is too close to the edges
	if (cornerSector.x < 1 || cornerSector.y < 1 
		|| cornerSector.x > pGrid->getXSectors() - 2
		|| cornerSector.y > pGrid->getYSectors() - 2)
	{
		return false;
	}
	//if part of the 2x2 square of the gun is over anything but a vacant square inside an active shield
	if (pGrid->getSectorValue((int)cornerSector.x, (int)cornerSector.y) != kST_insideShield ||
		pGrid->getSectorValue((int)cornerSector.x+1, (int)cornerSector.y) != kST_insideShield ||
		pGrid->getSectorValue((int)cornerSector.x, (int)cornerSector.y+1) != kST_insideShield ||
		pGrid->getSectorValue((int)cornerSector.x+1, (int)cornerSector.y+1) != kST_insideShield )
	{
		return false;
	}
	
	//set the shieldGrid to have an activeObject under where the gun fits in (a 2x2 grid)
	pGrid->setSector((int)cornerSector.x, (int)cornerSector.y, kST_activeObject ); //all guns start inactive
	pGrid->setSector((int)cornerSector.x+1, (int)cornerSector.y, kST_activeObject );
	pGrid->setSector((int)cornerSector.x, (int)cornerSector.y+1, kST_activeObject );
	pGrid->setSector((int)cornerSector.x+1, (int)cornerSector.y+1, kST_activeObject );
	
	//place pixel coordinate of gun at the center of the 2x2 grid
	x = (cornerSector.x+1) * pGrid->getSectorSize();
	y = (cornerSector.y+1) * pGrid->getSectorSize();
	moveTo(x, y);
	inGame = true;
	active = true;
	
	return true;
}

int sb_Gun::fitIntoGrid( float dotX, float dotY )
{
	float oldX, oldY;
	moveTo(dotX, dotY);
	if (fitIntoGrid())
	{
		return true;
	}
	else
	{
		moveTo(oldX, oldY);
		return false;
	}
}

int sb_Gun::pointIsInside(float dotX, float dotY )
{
	int sectorSize = pGrid->getSectorSize();
	if (dotX > x-sectorSize && dotX < x+sectorSize
        && dotY > y-sectorSize && dotY < y+sectorSize)
	{
		return true;
	}
	else
	{
		return false;
	}
}

float sb_Gun::getX()
{
	return x;
}

float sb_Gun::getY()
{
	return y;
}