//Copyright (c) 2004 Aaron Sullivan. All rights reserved.
#include "sb_Missile.h"

sb_Missile::sb_Missile()
{
	x = 0.0f;
	y = 0.0f;
	originX = 0.0f;
	originY = 0.0f;
	targetX = 10.0f;
	targetY = 10.0f;
	forceX = 0.0f;
	forceY = 0.0f;
	rotation = 0.0f;
	rotationSpeed = 0.2f;
	speed = 0.06f;
	blast.init(0.0f, 0.0f, 1.0f);
	active = false;
	exploding = false;
	needToPlaySound  = false;
	
	setColor(1.0f, 0.8f, 0.0f, 0.6f);
	
	time = 0;

}

void sb_Missile::launch( float newTargetX, float newTargetY )
{
	originX = x;
	originY = y;
	targetX = newTargetX;
	targetY = newTargetY;
	forceX = 0.0f;
	forceY = 0.0f;
	active = true;
	speed = 0.06f;
	rotationSpeed = 0.2f;
	
	blast.init(x, y, 200.0f);
	if (blast.isInContactWith(targetX, targetY))
	{
		speed = 0.02;
		rotationSpeed = 0.3;
	}
	blast.init(x , y, 1.0f);
	
	trailEnd = 0;
	trailPoint[trailEnd].x = x;
	trailPoint[trailEnd].y = y;
	onStraightTrail = false;
	trailIsFading = false;
	trailAlpha = 0.1f;
	fading = false; 
	
	needToPlaySound = false;
	
	time = 0;
}

int sb_Missile::isActive()
{
	return active;
}

int sb_Missile::isExploding()
{
	return exploding;
}

void sb_Missile::animate( Uint32 ticksPassed )
{
	
	if (active)
	{
		int itRotated = true;
		
		time += ticksPassed;
		
		if (trailIsFading)
		{
			trailAlpha -= 0.0001f * ticksPassed;
			if (trailAlpha <= 0.0f)
			{
				trailAlpha = 0.0f;
				trailIsFading = false;
			}
		}
		
		if (!exploding && !fading)
		{
			//try to match correct trajectory to approach target
			float targetAngle = angleToTarget();
			float halfway;
			if (rotation > targetAngle - 0.3 && rotation < targetAngle + 0.3)
			{
				rotation = targetAngle;
				itRotated = false;
				onStraightTrail = true;
			}
			else
			{
				if (rotation < 180)
				{
					halfway = rotation + 180;
					if (targetAngle > rotation && targetAngle < halfway)
					{
						//go clockwise
						rotate( (float)(rotationSpeed * ticksPassed) );
					}
					else
					{
						//go counter-clockwise
						rotate( (float)(-rotationSpeed * ticksPassed) );
					}
				}
				else if (rotation >= 180)
				{
					halfway = rotation - 180;
					if (targetAngle < rotation && targetAngle > halfway)
					{
						//go counter-clockwise
						rotate( (float)(-rotationSpeed * ticksPassed) );
					}
					else
					{
						//go clockwise
						rotate( (float)(rotationSpeed * ticksPassed) );
					}
				}
			}

			//if we are very close to the target... slow down
			float originalR = blast.getRadius();
			blast.init(x, y, 50.0f);
			if (blast.isInContactWith(targetX, targetY))
			{
				speed = speed - 0.0002f * (float)ticksPassed;
				if (speed <= 0.03f) speed = 0.03f;
				rotationSpeed = 0.4;
			}
			else if (time > 1500 && time <= 3500)
			{
				rotationSpeed = 0.4;
			}
			
			blast.init(x, y, 4.0f);
			if (blast.isInContactWith(targetX, targetY))
			{
				exploding = true;
				x = targetX;
				y = targetY;
				trailIsFading = true;
				needToPlaySound = true;
			}
			blast.setRadius(originalR);
			
			//after 3 and a half seconds of roaming it might be in a tight circle so...
			if (time > 3500)
			{
				//slow down even more
				speed = 0.01f;
				rotationSpeed = 0.4;
			}
			if (time > 6000) //after six seconds we cheat to hit the target!
			{
				exploding = true;
				x = targetX;
				y = targetY;
				trailIsFading = true;
				needToPlaySound = true;
			}
			
			forceX = forceX * 0.9f; //"air" resistance
			forceY = forceY * 0.9f;
			
			//push missile forward
			float dX, dY;
			dX = speed * (float)ticksPassed * sb_cosD(rotation); //find change in X based on angle of rotation
			dY = speed * (float)ticksPassed * sb_sinD(rotation); //find change in Y based on angle of rotation
	
			
			forceX = forceX + dX;
			forceY = forceY + dY;
			
			x += forceX;
			y += forceY;
			
			//update trail points
			if ((time % 5 == 0 && itRotated) || onStraightTrail && itRotated)
			{
				trailEnd++;
				if (trailEnd >= totalTrailPoints)
				{
					trailEnd--;
					trailIsFading = true;
				}
				else
				{
					trailPoint[trailEnd].x = x;
					trailPoint[trailEnd].y = y;
				}
				onStraightTrail = false;
			}
		}
		else if (exploding) //if we aren't animating the missile it's the explosion and the fading trail
		{
			blast.setRadius(blast.getRadius()+0.1f * ticksPassed);
			if (blast.getRadius() > 12.0f)
			{
				blast.setRadius(12.0f);
				active = true;
				exploding = false;
				if (trailIsFading)
				{
					fading = true;
				}
				else
				{
					active = false;
				}
			}

		}
		else if (fading)
		{
			if (trailAlpha == 0.0f)
			{
				fading = false;
				active = false;
			}
		}
	}
}

void sb_Missile::draw()
{
	if (active)
	{
		drawTrail();
		if (!exploding && !fading)
		{
			glAAFlush();
			glLoadIdentity();
			glAABegin(GL_POINTS);
			glAAVertex2f(targetX, targetY);
			glAAEnd();
			
			glAAFlush();
			glLoadIdentity();
			glTranslatef( x, y, 0.0f );
			glRotatef( rotation, 0.0f, 0.0f, 1.0f );
			glAAColor4f(r,g,b,a);
			glAALineWidth(2.0f);
			
			glAABegin(GL_LINE_STRIP);
			glAAVertex2f(0.0f, -2.0f);
			glAAVertex2f(0.0f, 2.0f);
			glAAVertex2f(6.0f, 0.0f);
			glAAVertex2f(0.0f, -2.0f);
			glAAEnd();
		}
		else if (exploding)
		{
			glAAFlush();
			glLoadIdentity();
			glTranslatef( x, y, 0.0f );
			glRotatef( rotation, 0.0f, 0.0f, 1.0f );
			glAAColor4f(r,g,b,a);
			glAALineWidth(2.0f);
			
			float radius = blast.getRadius();
			
			glAABegin(GL_LINE_STRIP);
			glAAVertex2f(-radius, 0);
			glAAVertex2f(0, -radius);
			glAAVertex2f(radius, 0);
			glAAVertex2f(0, radius);
			glAAVertex2f(-radius, 0);
			glAAEnd();
		}
	}

}

void sb_Missile::moveTo( float newX, float newY )
{
	x = newX;
	y = newY;
}

void sb_Missile::setRotation( float newRotation )
{
	rotation = newRotation;
}

void sb_Missile::rotate( float degrees )
{
	float tempRotation;
	tempRotation = rotation + degrees;
	if (tempRotation >= 360.0f)
	{
		rotation = tempRotation - 360;
	}
	else if (tempRotation < 0.0f)
	{
		rotation = 360 + tempRotation;
	}
	else
	{
		rotation = tempRotation;
	}
}

void sb_Missile::setSpeed( float newSpeed )
{
	speed = newSpeed;
}

void sb_Missile::setColor(float red, float green, float blue, float alpha)
{
	r = CLAMP(red, 0.0f, 1.0f);
	g = CLAMP(green, 0.0f, 1.0f);
	b = CLAMP(blue, 0.0f, 1.0f);
	a = CLAMP(alpha, 0.0f, 1.0f);
}


sb_Circle sb_Missile::getBlastCircle()
{
	return blast;
}

float sb_Missile::angleToTarget() //find correct rotation to point at target point
{
	float angle;
	float slope = (targetY - y) / (targetX - x);
	
	angle = sb_atanD( slope );
	
	if (targetX < x) 
	{
		angle = angle + 180;
	}

	if (angle >= 360.0f)
	{
		angle = angle - 360;
	}
	else if (angle < 0.0f)
	{
		angle = 360 + angle;
	}

	return angle;
}

void sb_Missile::drawTrail()
{
	int i;
	glAAFlush();
	glLoadIdentity();
	glAAColor4f(1.0f, 1.0f, 1.0f, trailAlpha);
	glAALineWidth(3.0f);
	glAABegin(GL_LINE_STRIP);
	if (trailEnd != totalTrailPoints-1)
	{
		glAAVertex2f(x,y);
	}
	for (i=trailEnd; i >= 0; i--)
	{
		glAAVertex2f(trailPoint[i].x, trailPoint[i].y);
	}
	glAAEnd();
}

int sb_Missile::needToPlayExplodeSound()
{
	int temp = needToPlaySound;
	needToPlaySound = false; //this assumes that whoever calls this function will play the sound for us
	return temp;
}

void sb_Missile::makeInactive()
{
	active = false;
}