//Copyright (c) 2004 Aaron Sullivan. All rights reserved.
#include "sb_Noisemaker.h"
#include <iostream.h>

sb_Noisemaker::sb_Noisemaker()
{
	int rate = SB_DEFAULT_SOUND_RATE;
    Uint16 format = MIX_DEFAULT_FORMAT;
    int channels = SB_DEFAULT_SOUND_CHANNELS;
    int buffers = SB_DEFAULT_SOUND_BUFFERS;
	
	int frq, ch;  //these would be used to get information about the current Audio Device settings, but when sent
	Uint16 fmt;   //to Mix_QuerySpec(). We won't use the returned values, though, we just want to know if it fails.
	
	
	if (!Mix_QuerySpec( &frq, &fmt, &ch ) ) //if the Audio device has not been opened yet, let's open it.
	{
		if(Mix_OpenAudio(rate, format, channels, buffers)) //open the device with our settings
		{
			cout << ("Unable to open audio! (in sb_noisemaker.cpp)\n");
		}
	}
	
	Mix_AllocateChannels(SB_NOISECHANNELSDEFAULT);
	allocatedNoiseChannels = SB_NOISECHANNELSDEFAULT;
	
	int i;
	for (i=0; i<SB_NOISEINDEXMAX; i++)
	{	
		chunk[i] = NULL;
	}	
	
}

sb_Noisemaker::sb_Noisemaker(int noiseChannels)
{
	int rate = SB_DEFAULT_SOUND_RATE;
    Uint16 format = MIX_DEFAULT_FORMAT;
    int channels = SB_DEFAULT_SOUND_CHANNELS;
    int buffers = SB_DEFAULT_SOUND_BUFFERS;
		
	if(Mix_OpenAudio(rate, format, channels, buffers)) //open the device with our settings
	{
		cout << ("Unable to open audio!\n");
	}
	
	Mix_AllocateChannels(noiseChannels);
	allocatedNoiseChannels = noiseChannels;
	
	int i;
	for (i=0; i<SB_NOISEINDEXMAX; i++)
	{	
		chunk[i] = NULL;
	}	
	
}

sb_Noisemaker::~sb_Noisemaker()
{
	int i;
	for (i=0; i<allocatedNoiseChannels; i++)
	{
		free(i);
	}
	
	Mix_CloseAudio();
}

void sb_Noisemaker::load(char * filename, int noiseIndex)
{
	if (noiseIndex >= 0 && noiseIndex < SB_NOISEINDEXMAX)
	{
		if (chunk[noiseIndex] != NULL)
		{
			free(noiseIndex);
		}
		chunk[noiseIndex] = Mix_LoadWAV(filename); //doesn't mean just wave... takes other formats like .ogg, aiff
	}
}

void sb_Noisemaker::play(int noiseIndex)
{
	Mix_PlayChannel(-1, chunk[noiseIndex], 0); //-1 means first available channel, 0 means loop zero times (play once)
}

void sb_Noisemaker::free(int noiseIndex)
{
	int channelIndex;
	if (noiseIndex >= 0 && noiseIndex < SB_NOISEINDEXMAX)
	{
		if (chunk[noiseIndex] != NULL)
		{
			//before freeing it we should be sure it isn't playing in any channels
			//check for this particular noise playing in every channel
			//every channel it is currently playing (or was last played in) is stopped
			for(channelIndex=0; channelIndex<allocatedNoiseChannels; channelIndex++)
			{
				if (chunk[noiseIndex] == Mix_GetChunk(channelIndex))
				{
					Mix_HaltChannel(channelIndex);
				}
			}
			
			//now that we know it's not being played we can free and NULL it
			Mix_FreeChunk(chunk[noiseIndex]);
			chunk[noiseIndex] = NULL;
		}
	}
}

