//Copyright (c) 2004 Aaron Sullivan. All rights reserved.
#include "sb_Phase_Battle.h"
#include "iostream.h"
#include "sb_Missile.h"

sb_Phase_Battle::sb_Phase_Battle( sb_GamePtr gameToUse) 
: sb_GamePhase( gameToUse ) //call sb_GamePhase constructor
{
	game = gameToUse;
	
	reset();
}

sb_Phase_Battle::~sb_Phase_Battle()
{
	
}

void sb_Phase_Battle::start()
{
	done = false;
	time = 0;
	secondsLeft = totalSeconds;
	
	//title variables
	titleX = 12.0f, titleY = 745.0f;
	titleAlpha = 0.8f;
	titleScaleX = 10.0f;
	titleScaleY = 2.0f;
	titleGlow = 0.0f;
	
	//phase specific
	battling = false;
	waitingForMissiles = false;
	
	game->musicBox.play(kMusic_battle);
	
	//start keeping track of Ticks passed
	game->updateTicksPassed();
}

void sb_Phase_Battle::pause()
{
	game->musicBox.pauseToggle();
}

void sb_Phase_Battle::end()
{
	done = true;
}

void sb_Phase_Battle::reset()
{
	totalSeconds = 15;
	//start();
}

void sb_Phase_Battle::processEvent( SDL_Event &event )
{
	switch (event.type)
	{
		//pointer position comes from game object ( which has its own processEvent function )
		case SDL_MOUSEBUTTONDOWN:
			if (battling)
			{
				int i;
				for (i=0; i <= game->indexOfLastGun; i++)
				{
					if (game->gun[i].isActive() && game->gun[i].isReloading() == false)
					{
						if (game->playerMissiles.launch(game->gun[i].getX(), game->gun[i].getY(), 
														game->gun[i].getRotation(), 
														game->pointerX, game->pointerY, 0))
						{
							game->noisemaker.play(kFX_playerMissile);
							game->gun[i].reload(); //start the delayed reload
							break;
						}
					}
					
				}
				if (i > game->indexOfLastGun) //if there were no guns available to fire... or no missiles available
				{
					game->noisemaker.play(kFX_click); //audio que for failed shot
				}
			}
			
			/* uncomment if you want opening animation to be skipable
			else if(time > 200)
		{
				battling = true;
				timeBattleStarted = time;
				bargesShowing = 5;
		}
			*/
			break;
		case SDL_MOUSEBUTTONUP:
			break;
		case SDL_KEYDOWN:
			if (event.key.keysym.sym == SDLK_SPACE)
			{
				//skip animated intro? 
			}
			//'F' fades out music
			if (event.key.keysym.sym == SDLK_f)
			{
				game->musicBox.fadeOut();
			}
			//'M' toggles music on and off
			if (event.key.keysym.sym==SDLK_m)
			{
				if(game->musicBox.isPlaying())
				{
					game->musicBox.stop();
				}
				else
				{
					game->musicBox.play();
				}
			}
			break;
		case SDL_KEYUP:
			break;
		default:
			break;
	}
}

void sb_Phase_Battle::animate()
{
	if (done) return; //necessary so that last gun placed does not move
	
	int i;
	Uint32 ticksPassed;
	game->updateTicksPassed();
	ticksPassed = game->getTicksPassed();
	
	//Time based events
	time = time + ticksPassed;
	
	Uint32 startTime, endTime;
	float transitionTime; //will hold amount 
	
	for (i=0; i <= game->indexOfLastGun; i++)
	{
		game->gun[i].animate( ticksPassed ); 
	}
	
	game->playerMissiles.animate( ticksPassed );
	if (game->playerMissiles.explodeSound())
	{
		game->noisemaker.play(kFX_missileBlast);
	}
	
	if (time > 500 && battling == false && waitingForMissiles == false)
	{
		battling = true;
		game->destroyers.go();
		timeBattleStarted = 500;
	}
	
	if (battling)
	{
		//animate the title of the phase
		//"stretch in"
		startTime = timeBattleStarted; endTime = timeBattleStarted+500; transitionTime = (float)(endTime - startTime - 1);
		if (time > startTime && time < endTime)
		{
			//the total amount to change (over whole time) is divided total time of transition and multiplied by how many ticks passed 
			//then that portion (which is the fraction needed for THIS update) is subtracted from the current value
			titleScaleX -= 9.0f/transitionTime*ticksPassed;
		}
		if (time > endTime) titleScaleX = 1.0f; //take care of inaccuracy of method
		
		//glow the title
		startTime = timeBattleStarted+500; endTime = timeBattleStarted+1000; transitionTime = (float)(endTime - startTime - 1);
		if (time > startTime && time < endTime)
		{
			if (titleGlow == 0.0f)
			{
				titleGlow = 1.0f;
			}
			titleGlow -= 1.0/transitionTime*ticksPassed;
		}
		if (time > endTime) titleGlow = 0.0f;
		
		//raise and vanish title
		startTime = timeBattleStarted+2500; endTime = timeBattleStarted+3000; transitionTime = (float)(endTime - startTime - 1);
		if (time > startTime && time < endTime)
		{
			titleY -= 100.0f/transitionTime*ticksPassed; 
			titleAlpha -= 0.8f/transitionTime*ticksPassed;
			if (titleAlpha < 0.0f) titleAlpha = 0.0f;
			titleScaleY += 10.0f/transitionTime*ticksPassed;
		}
		if (time >= endTime) {
			titleY = 0.0;
			titleAlpha = 0.0f;
			titleScaleY = 4.0f;
		}
		
		//timer
		//*this phase is ended when the timer (secondsLeft) runs out
		secondsLeft = totalSeconds - (time-timeBattleStarted)/1000; //time/1000 turns milliseconds into seconds
		if (secondsLeft < 0)
		{
			secondsLeft = 0;
			battling = false;
			timeBattleEnded = time;
			waitingForMissiles = true;
			game->destroyers.stop();
			game->musicBox.fadeOut();
		}
		
		//destroyers
		game->destroyers.animate( ticksPassed );
		
	}
	
	sb_Circle dCircle;
	int dIndex;
	dCircle = game->destroyers.getNextCollisionCircle(dIndex); //dIndex is updated
	while (dIndex > -1)
	{
		//if any player missiles are exploding on this destroyer damage it
		if (game->playerMissiles.anyCollisionWith(dCircle))
		{
			game->destroyers.damage(dIndex);
			game->noisemaker.play(kFX_missileHit);
		}
		//if this destroyer is over a vacant spot, it means they have come into close range of
		//the barges and the game is over
		if (game->grid.getSectorValue((int)(dCircle.getX() / game->grid.getSectorSize()), (int)(dCircle.getY() / game->grid.getSectorSize()))
			!= kST_outOfRange)
		{
			game->gameover = true;
			end();
		}
		dCircle = game->destroyers.getNextCollisionCircle(dIndex); //dIndex is updated
	}
	
	//if all the destroyers are gone, end wave
	if (battling && game->destroyers.allInactive())
	{
		secondsLeft = 0;
		battling = false;
		timeBattleEnded = time;
		waitingForMissiles = true;
		game->destroyers.stop();
		game->musicBox.fadeOut();
	}
	
	//we wait for the missiles to finish their path
	if (waitingForMissiles)
	{
		game->destroyers.animate( ticksPassed );
		if (game->playerMissiles.allInactive() && game->destroyers.isStopped())
		{
			waitingForMissiles = false;
			//if we are on or past the third stage there are no more new enemy reinforcements... so we'll move on to the next stage
			if (game->destroyers.allInactive() && game->currentWave >= 3)
			{
				game->newWave = true; //let the newWave phase take care of advancing us to the next Stage
				waitingForMissiles = true;
			}
			//on to the next wave
			end();
		}
	}
}

void sb_Phase_Battle::draw()
{
	glMatrixMode(GL_MODELVIEW); //we select the Model matrix to do our drawing
	
	glBindTexture(GL_TEXTURE_2D, glAA_texture[0]);
	game->grid.displayShields();
	
	int i;
	for (i=0; i < game->totalBarges; i++)
	{
		game->barge[i].draw();
	}
	
	for (i=0; i <= game->indexOfLastGun; i++)
	{
		game->gun[i].draw();
	}
	
	game->playerMissiles.draw();
	
	if (battling)
	{
		drawTitle();
		drawTimer();
		drawPointer();
	}
	
	game->destroyers.draw();
}

void sb_Phase_Battle::drawTimer()
{
	glAAFlush();
	glLoadIdentity();
	glBindTexture(GL_TEXTURE_2D, glAA_texture[0]);
	vf_setpenscale(3.5f, 3.5f);
	vf_setpenloc( 10.0f, 690.0f );
	glAALineWidth(3);
	glAAColor4f(1.0f, 1.0f, 1.0f, 0.5f);
	if (secondsLeft >= 10)
	{
		vecString("%d", secondsLeft);
	}
	else
	{
		vecString("0%d", secondsLeft);
	}
}

void sb_Phase_Battle::drawTitle()
{
	vf_setpentrack(8.0f, 0.0f);
	if (titleGlow > 0.0f)
	{	
		glAAFlush();
		glLoadIdentity();
		glBindTexture(GL_TEXTURE_2D, glAA_texture[2]);
		vf_setpenscale(titleScaleX, titleScaleY);
		vf_setpenloc( titleX, titleY );
		glAALineWidth(10);
		glAAColor4f(1.0f, 1.0f, 1.0f, titleGlow);
		vecString("OPEN FIRE!");
	}
	
	glAAFlush();
	glLoadIdentity();
	glBindTexture(GL_TEXTURE_2D, glAA_texture[0]);
	vf_setpenscale(titleScaleX, titleScaleY);
	vf_setpenloc( titleX, titleY );
	glAALineWidth(3);
	glAAColor4f(1.0f, 1.0f, 1.0f, titleAlpha);
	vecString("OPEN FIRE!");
}

void sb_Phase_Battle::drawPointer()
{
	glAAFlush();
	glLoadIdentity();
	glTranslatef(game->pointerX, game->pointerY, 0.0f);
	glAALineWidth(2);
	glAAColor4f(1.0f, 1.0f, 0.0f, 0.6f);
	glAABegin(GL_LINE_STRIP);
	glAAVertex2f(0.0f,0.0f);
	glAAVertex2f(0.0f,15.0f);
	glAAVertex2f(4.0f,10.0f);
	glAAVertex2f(12.0f,12.0f);
	glAAVertex2f(0.0f,0.0f);
	glAAEnd();
	glAAColor4f(1.0f, 1.0f, 0.0f, 0.2f);
}