//Copyright (c) 2004 Aaron Sullivan. All rights reserved.
#include "sb_Phase_GameOver.h"
#include "iostream.h"
#include "sb_Barge.h"

sb_Phase_GameOver::sb_Phase_GameOver( sb_GamePtr gameToUse) 
: sb_GamePhase( gameToUse ) //call sb_GamePhase constructor
{
	game = gameToUse;
	gameUtil.init(game);
	
	reset();
}

sb_Phase_GameOver::~sb_Phase_GameOver()
{
	
}

void sb_Phase_GameOver::start()
{
	done = false;
	time = 0;
	
	//title variables
	titleX = 280.0f, titleY = 300.0f;
	titleAlpha = 0.8f;
	titleScaleX = 50.0f;
	titleScaleY = 8.0f;
	titleGlow = 0.0f;
	
	//phase specific
	showingGameOver = false;
	erasingGameOver = false;
	
	game->musicBox.play(kMusic_gameover);
	
	//start keeping track of Ticks passed
	game->updateTicksPassed();
}

void sb_Phase_GameOver::pause()
{
	game->musicBox.pauseToggle();
}

void sb_Phase_GameOver::end()
{
	done = true;
}

void sb_Phase_GameOver::reset()
{
	showingGameOver = false;
}

void sb_Phase_GameOver::processEvent( SDL_Event &event )
{
	int i;
	switch (event.type)
	{
		//pointer position comes from game object ( which has its own processEvent function )
		case SDL_MOUSEBUTTONDOWN:
			//no interactivity in this phase
			if (showingGameOver)
			{
				erasingGameOver = true; //when title is erased this phase will end()
				showingGameOver = false; 
				timeGameOverEnded = time;
				game->musicBox.fadeOut(400);
			}
			break;
		case SDL_MOUSEBUTTONUP:
			break;
		case SDL_KEYDOWN:
			if (event.key.keysym.sym == SDLK_SPACE)
			{
				//skip animated intro? 
			}
			//'F' fades out music
			if (event.key.keysym.sym == SDLK_f)
			{
				game->musicBox.fadeOut(1000);
			}
			//'M' toggles music on and off
			if (event.key.keysym.sym==SDLK_m)
			{
				if(game->musicBox.isPlaying())
				{
					game->musicBox.stop();
				}
				else
				{
					game->musicBox.play();
				}
			}
			break;
		case SDL_KEYUP:
			break;
		default:
			break;
	}
}

void sb_Phase_GameOver::animate()
{
	int i;
	Uint32 ticksPassed;
	game->updateTicksPassed();
	ticksPassed = game->getTicksPassed();
	
	//Time based events
	time = time + ticksPassed;
	
	Uint32 startTime, endTime;
	float transitionTime; //will hold amount 
	
	if (time > 500 && erasingGameOver == false && showingGameOver == false)
	{
		showingGameOver = true;
		timeGameOverStarted = 500;
	}
	
	if (showingGameOver)
	{
		//animate the title of the phase
		//"stretch in"
		startTime = timeGameOverStarted; endTime = timeGameOverStarted+500; transitionTime = (float)(endTime - startTime - 1);
		if (time > startTime && time < endTime)
		{
			//the total amount to change (over whole time) is divided total time of transition and multiplied by how many ticks passed 
			//then that portion (which is the fraction needed for THIS update) is subtracted from the current value
			titleScaleX -= 47.0f/transitionTime*ticksPassed;
		}
		if (time > endTime) titleScaleX = 3.0f; //take care of inaccuracy of method
		
		//glow the title
		startTime = timeGameOverStarted+500; endTime = timeGameOverStarted+1000; transitionTime = (float)(endTime - startTime - 1);
		if (time > startTime && time < endTime)
		{
			if (titleGlow == 0.0f)
			{
				titleGlow = 1.0f;
			}
			titleGlow -= 1.0/transitionTime*ticksPassed;
		}
		if (time > endTime) 
		{
			titleGlow = 0.0f;
		}
	}
	
	if (erasingGameOver)
	{
		//raise and vanish title
		startTime = timeGameOverEnded; endTime = timeGameOverEnded+500; transitionTime = (float)(endTime - startTime - 1);
		if (time > startTime && time < endTime)
		{
			titleY -= 200.0f/transitionTime*ticksPassed; 
			titleAlpha -= 0.8f/transitionTime*ticksPassed;
			if (titleAlpha < 0.0f) titleAlpha = 0.0f;
			titleScaleY += 30.0f/transitionTime*ticksPassed;
		}
		if (time >= endTime) {
			titleY = 0.0;
			titleAlpha = 0.0f;
			titleScaleY = 4.0f;
			//make sure there is no residual effect from this game
			game->reset();
			end();
		}
	}
}

void sb_Phase_GameOver::draw()
{
	glMatrixMode(GL_MODELVIEW); //we select the Model matrix to do our drawing
	
	if (showingGameOver || erasingGameOver)
	{
		drawGameOver();
	}
	
	game->grid.displayShields();
	
	game->destroyers.draw();
	
	int i;
	for (i=0; i < game->totalBarges; i++)
	{
		game->barge[i].draw();
	}
	
	for (i=0; i <= game->indexOfLastGun; i++)
	{
		game->gun[i].draw();
	}
	
}


void sb_Phase_GameOver::drawGameOver()
{
	vf_setpentrack(8.0f, 0.0f);
	if (titleGlow > 0.0f)
	{	
		glAAFlush();
		glLoadIdentity();
		glBindTexture(GL_TEXTURE_2D, glAA_texture[2]);
		vf_setpenscale(titleScaleX, titleScaleY);
		vf_setpenloc( titleX, titleY );
		glAALineWidth(10);
		glAAColor4f(1.0f, 0.0f, 0.0f, titleGlow);
		vecString("G A M E  O V E R");
	}
	
	glAAFlush();
	glLoadIdentity();
	glBindTexture(GL_TEXTURE_2D, glAA_texture[0]);
	vf_setpenscale(titleScaleX, titleScaleY);
	vf_setpenloc( titleX, titleY );
	glAALineWidth(3);
	glAAColor4f(1.0f, 0.2f, 0.2f, titleAlpha);
	vecString("G A M E  O V E R");
	
	glAAFlush();
	glLoadIdentity();
	glBindTexture(GL_TEXTURE_2D, glAA_texture[2]);
	vf_setpentrack(1.0f, 0.0f);
	vf_setpenscale(1.5f, 1.5f);
	vf_setpenloc( 221, 700 );
	glAALineWidth(2);
	glAAColor4f(1.0f, 1.0f, 1.0f, titleAlpha);
	vecString("You made it to level %d. Visit www.iDevGames.com today!", game->currentLevel);
}