//Copyright (c) 2004 Aaron Sullivan. All rights reserved.
#include "sb_Phase_NewWave.h"
#include "iostream.h"
#include "sb_Barge.h"

sb_Phase_NewWave::sb_Phase_NewWave( sb_GamePtr gameToUse) 
: sb_GamePhase( gameToUse ) //call sb_GamePhase constructor
{
	game = gameToUse;
	gameUtil.init(game);
	
	reset();
}

sb_Phase_NewWave::~sb_Phase_NewWave()
{
	
}

void sb_Phase_NewWave::start()
{
	done = false;
	time = 0;
	secondsLeft = totalSeconds;
	
	//title variables
	titleX = 12.0f, titleY = 745.0f;
	titleAlpha = 0.8f;
	titleScaleX = 10.0f;
	titleScaleY = 2.0f;
	titleGlow = 0.0f;
	
	//phase specific
	testingForEnclosure = true;
	currentBarge = 0;
	showingTitle = false;
	addingEnemies = false;
	showingLevelComplete = false;
	
	game->currentWave++;
	
	//if we are past the 3rd wave there are no more new enemies
	//so if all the enemies are gone, this stage is complete and it's time to move on to the next stage
	if (game->currentWave > 3 && game->destroyers.allInactive())
	{
		showingLevelComplete = true;
		game->musicBox.playOnce(kMusic_levelComplete);
	}
	else
	{
		//test to see if the player successfully enclosed at least one barge
		gameUtil.testForEnclosures();
		if (game->totalEnclosures <= 0)
		{
			game->gameover = true;
			end();
		}
	}

	
	//start keeping track of Ticks passed
	game->updateTicksPassed();
}

void sb_Phase_NewWave::pause()
{
	game->musicBox.pauseToggle();
}

void sb_Phase_NewWave::end()
{
	done = true;
}

void sb_Phase_NewWave::reset()
{
	totalSeconds = 4;
	testingForEnclosure = true;
	showingTitle = false;
}

void sb_Phase_NewWave::processEvent( SDL_Event &event )
{
	int i;
	switch (event.type)
	{
		//pointer position comes from game object ( which has its own processEvent function )
		case SDL_MOUSEBUTTONDOWN:
			//no interactivity in this phase
			break;
		case SDL_MOUSEBUTTONUP:
			break;
		case SDL_KEYDOWN:
			if (event.key.keysym.sym == SDLK_SPACE)
			{
				//skip animated intro? 
			}
			//'F' fades out music
			if (event.key.keysym.sym == SDLK_f)
			{
				game->musicBox.fadeOut();
			}
			//'M' toggles music on and off
			if (event.key.keysym.sym==SDLK_m)
			{
				if(game->musicBox.isPlaying())
				{
					game->musicBox.stop();
				}
				else
				{
					game->musicBox.play();
				}
			}
			break;
		case SDL_KEYUP:
			break;
		default:
			break;
	}
}

void sb_Phase_NewWave::animate()
{
	int i;
	Uint32 ticksPassed;
	game->updateTicksPassed();
	ticksPassed = game->getTicksPassed();
	
	//Time based events
	time = time + ticksPassed;
	
	Uint32 startTime, endTime;
	float transitionTime; //will hold amount 
	
	if (time > 500 && testingForEnclosure && !showingLevelComplete)
	{
		showingTitle = true;
		testingForEnclosure = false;
		timeTitleStarted = 500;
	}
	
	if (showingTitle)
	{
		//animate the title of the phase
		//"stretch in"
		startTime = timeTitleStarted; endTime = timeTitleStarted+500; transitionTime = (float)(endTime - startTime - 1);
		if (time > startTime && time < endTime)
		{
			//the total amount to change (over whole time) is divided total time of transition and multiplied by how many ticks passed 
			//then that portion (which is the fraction needed for THIS update) is subtracted from the current value
			titleScaleX -= 9.0f/transitionTime*ticksPassed;
		}
		if (time > endTime) titleScaleX = 1.0f; //take care of inaccuracy of method
		
		//glow the title
		startTime = timeTitleStarted+500; endTime = timeTitleStarted+1000; transitionTime = (float)(endTime - startTime - 1);
		if (time > startTime && time < endTime)
		{
			if (titleGlow == 0.0f)
			{
				titleGlow = 1.0f;
			}
			titleGlow -= 1.0/transitionTime*ticksPassed;
		}
		if (time > endTime) titleGlow = 0.0f;
		
		//raise and vanish title
		startTime = timeTitleStarted+2500; endTime = timeTitleStarted+3000; transitionTime = (float)(endTime - startTime - 1);
		if (time > startTime && time < endTime)
		{
			titleY -= 100.0f/transitionTime*ticksPassed; 
			titleAlpha -= 0.8f/transitionTime*ticksPassed;
			if (titleAlpha < 0.0f) titleAlpha = 0.0f;
			titleScaleY += 10.0f/transitionTime*ticksPassed;
		}
		if (time > endTime) {
			titleY = 0.0;
			titleAlpha = 0.0f;
			titleScaleY = 4.0f;
			timeTitleEnded = time;
			showingTitle = false;
			addingEnemies = true;
			//calculate number of enemies to add
			int numberOfEnemiesToLaunch;

			if (game->currentWave == 2) //1st wave is taken care of in SetStage phase
			{
				numberOfEnemiesToLaunch = (int)((20 + game->currentLevel * (CLAMP(game->currentLevel/4, 1, 200))) * 0.3f); //second wave is 30% of total
			}
			if (game->currentWave == 3)
			{
				numberOfEnemiesToLaunch = (int)((20 + game->currentLevel * (CLAMP(game->currentLevel/4, 1, 200))) * 0.5f); //third wave is 50% of total
			}
			if (game->currentWave > 3)
			{
				numberOfEnemiesToLaunch = 1;
			}
			game->destroyers.launch(numberOfEnemiesToLaunch);
			game->noisemaker.play(kFX_tactical4);
		}
		
		//timer
		//*this phase is ended when the timer (secondsLeft) runs out
		/*secondsLeft = totalSeconds - (time-timeTitleStarted)/1000; //time/1000 turns milliseconds into seconds
		if (secondsLeft < 0)
		{
			secondsLeft = 0;
			showingTitle = false;
			timeTitleEnded = time;
		}
		*/
	}
	
	if (addingEnemies ) 
	{
//		startTime = timeTitleEnded; endTime = timeTitleEnded+1000; transitionTime = (float)(endTime - startTime - 1);
//		if (time > endTime)
//		{
			end();
//		}
	}
	
	if (showingLevelComplete && time > 3500)
	{
		game->currentLevel++;
		game->currentWave = 1;
		game->newStage = true;
		end();
	}
	
	for (i=0; i <= game->indexOfLastGun; i++)
	{
		game->gun[i].animate( ticksPassed );
	}
}

void sb_Phase_NewWave::draw()
{
	glMatrixMode(GL_MODELVIEW); //we select the Model matrix to do our drawing
	
	if (showingLevelComplete)
	{
		vf_setpentrack(8.0f, 0.0f);
		glAAFlush();
		glLoadIdentity();
		glBindTexture(GL_TEXTURE_2D, glAA_texture[0]);
		vf_setpenscale(3.0f, 6.0f);
		vf_setpenloc( 230, 275 );
		glAALineWidth(3.0f);
		glAAColor4f(1.0f, 1.0f, 0.2f, 0.5f);
		vecString("LEVEL %d COMPLETE", game->currentLevel);
	}
	else
	{
		if (showingTitle)
		{
			drawTitle();
		}
		
		glBindTexture(GL_TEXTURE_2D, glAA_texture[0]);
		
		
/*		if (testingForEnclosure)
		{
			game->grid.displayGrid(game->barge[currentBarge].getX(), game->barge[currentBarge].getY(), 100);
		}
*/		
		game->grid.displayShields();
		
		game->destroyers.draw();
		
		int i;
		for (i=0; i < game->totalBarges; i++)
		{
			game->barge[i].draw();
		}
		
		for (i=0; i <= game->indexOfLastGun; i++)
		{
			game->gun[i].draw();
		}
	}
}


void sb_Phase_NewWave::drawTitle()
{
	vf_setpentrack(8.0f, 0.0f);
	if (titleGlow > 0.0f)
	{	
		glAAFlush();
		glLoadIdentity();
		glBindTexture(GL_TEXTURE_2D, glAA_texture[2]);
		vf_setpenscale(titleScaleX, titleScaleY);
		vf_setpenloc( titleX, titleY );
		glAALineWidth(10);
		glAAColor4f(1.0f, 1.0f, 1.0f, titleGlow);
		vecString("WAVE %d", game->currentWave);
	}
	
	glAAFlush();
	glLoadIdentity();
	glBindTexture(GL_TEXTURE_2D, glAA_texture[0]);
	vf_setpenscale(titleScaleX, titleScaleY);
	vf_setpenloc( titleX, titleY );
	glAALineWidth(3);
	glAAColor4f(1.0f, 1.0f, 1.0f, titleAlpha);
	vecString("WAVE %d", game->currentWave);
}