//Copyright (c) 2004 Aaron Sullivan. All rights reserved.
#include "sb_Phase_PlaceGuns.h"
#include "iostream.h"
//#include "sb_Gun.h"

sb_Phase_PlaceGuns::sb_Phase_PlaceGuns( sb_GamePtr gameToUse) 
: sb_GamePhase( gameToUse ) //call sb_GamePhase constructor
{
	game = gameToUse;

	reset();
}

sb_Phase_PlaceGuns::~sb_Phase_PlaceGuns()
{
	
}

void sb_Phase_PlaceGuns::start()
{
	done = false;
	time = 0;
	secondsLeft = totalSeconds;
	
	//title variables
	titleX = 12.0f, titleY = 745.0f;
	titleAlpha = 0.8f;
	titleScaleX = 10.0f;
	titleScaleY = 2.0f;
	titleGlow = 0.0f;
	
	//phase specific
	waitingForChoice = false;
	
	//calculate number of guns to award
	//two for each active barge
	newGuns = 0;
	int i;
	for (i=0; i < game->totalBarges; i++)
	{
		if (game->barge[i].isActive()) newGuns += 2;
	}
	if (game->currentLevel == 1)
	{
		newGuns++;
	}

	indexOfGunPointer = game->indexOfLastGun + 1;
	if (indexOfGunPointer >= game->totalGuns)
	{
		end();
	}
	newGuns--;
	
	//start keeping track of Ticks passed
	game->updateTicksPassed();
}

void sb_Phase_PlaceGuns::pause()
{
	game->musicBox.pauseToggle();
}

void sb_Phase_PlaceGuns::end()
{
	done = true;
}

void sb_Phase_PlaceGuns::reset()
{
	totalSeconds = 10;
	//start();
}

void sb_Phase_PlaceGuns::processEvent( SDL_Event &event )
{
	switch (event.type)
	{
		//pointer position comes from game object ( which has its own processEvent function )
		case SDL_MOUSEBUTTONDOWN:
			
			if (event.button.button == SDL_BUTTON_LEFT)
			{
				if (waitingForChoice)
				{
					//check and see if gun fits where pointer is
					if (game->gun[indexOfGunPointer].fitIntoGrid())
					{
						game->indexOfLastGun++; //add the gun being used as a pointer to the list of active guns
						indexOfGunPointer = game->indexOfLastGun + 1;
						newGuns--;
						if (newGuns < 0)
						{
							end();
						}
						else
						{
							if (indexOfGunPointer >= game->totalGuns)
							{
								end();
							}
						}
					}
					else
					{
						game->noisemaker.play(kFX_buzz); //noise to let player know it didn't fit
					}
					
				}
			}
			else if (event.button.button == SDL_BUTTON_RIGHT)
			{
				totalSeconds--;
			}
			
			/* uncomment if you want opening animation to be skipable
			else if(time > 200)
			{
				waitingForChoice = true;
				timeChoiceStarted = time;
				bargesShowing = 5;
			}
			*/
			break;
		case SDL_MOUSEBUTTONUP:
			break;
		case SDL_KEYDOWN:
			if (event.key.keysym.sym == SDLK_SPACE)
			{
				totalSeconds--; 
			}
			//'F' fades out music
			if (event.key.keysym.sym == SDLK_f)
			{
				game->musicBox.fadeOut();
			}
			//'M' toggles music on and off
			if (event.key.keysym.sym==SDLK_m)
			{
				if(game->musicBox.isPlaying())
				{
					game->musicBox.stop();
				}
				else
				{
					game->musicBox.play();
				}
			}
			break;
		case SDL_KEYUP:
			break;
		default:
			break;
	}
}

void sb_Phase_PlaceGuns::animate()
{
	if (done) return; //necessary so that last gun placed does not move
	
	int i;
	Uint32 ticksPassed;
	game->updateTicksPassed();
	ticksPassed = game->getTicksPassed();
	
	//Time based events
	time = time + ticksPassed;
	
	Uint32 startTime, endTime;
	float transitionTime; //will hold amount 
	
	game->gun[indexOfGunPointer].moveTo(game->pointerX, game->pointerY);
	game->gun[indexOfGunPointer].animate( ticksPassed );
	
	for (i=0; i <= game->indexOfLastGun; i++)
	{
		game->gun[i].animate( ticksPassed ); 
	}
	
	if (time > 500)
	{
		waitingForChoice = true;
		timeChoiceStarted = 500;
	}
	
	if (waitingForChoice)
	{
		//animate the title of the phase
		//"stretch in"
		startTime = timeChoiceStarted; endTime = timeChoiceStarted+500; transitionTime = (float)(endTime - startTime - 1);
		if (time > startTime && time < endTime)
		{
			//the total amount to change (over whole time) is divided total time of transition and multiplied by how many ticks passed 
			//then that portion (which is the fraction needed for THIS update) is subtracted from the current value
			titleScaleX -= 9.0f/transitionTime*ticksPassed;
		}
		if (time > endTime) titleScaleX = 1.0f; //take care of inaccuracy of method
		
		//glow the title
		startTime = timeChoiceStarted+500; endTime = timeChoiceStarted+1000; transitionTime = (float)(endTime - startTime - 1);
		if (time > startTime && time < endTime)
		{
			if (titleGlow == 0.0f)
			{
				titleGlow = 1.0f;
			}
			titleGlow -= 1.0/transitionTime*ticksPassed;
		}
		if (time > endTime) titleGlow = 0.0f;
		
		//raise and vanish title
		startTime = timeChoiceStarted+2500; endTime = timeChoiceStarted+3000; transitionTime = (float)(endTime - startTime - 1);
		if (time > startTime && time < endTime)
		{
			titleY -= 100.0f/transitionTime*ticksPassed; 
			titleAlpha -= 0.8f/transitionTime*ticksPassed;
			if (titleAlpha < 0.0f) titleAlpha = 0.0f;
			titleScaleY += 10.0f/transitionTime*ticksPassed;
		}
		if (time >= endTime) {
			titleY = 0.0;
			titleAlpha = 0.0f;
			titleScaleY = 4.0f;
		}
		
		//timer
		//*this phase is ended when the timer (secondsLeft) runs out
		secondsLeft = totalSeconds - (time-timeChoiceStarted)/1000; //time/1000 turns milliseconds into seconds
		if (secondsLeft < 0)
		{
			secondsLeft = 0;
			waitingForChoice = false;
			timeChoiceEnded = time;
			//***until this is updated:
			end();
		}
	}
}

void sb_Phase_PlaceGuns::draw()
{
	glMatrixMode(GL_MODELVIEW); //we select the Model matrix to do our drawing
	
	if (waitingForChoice)
	{
		drawTitle();
		drawTimer();
		drawRemainingGuns();
		drawPointer();
	}
	
	glBindTexture(GL_TEXTURE_2D, glAA_texture[0]);
	game->grid.displayShields();
	
	int i;
	for (i=0; i < game->totalBarges; i++)
	{
		game->barge[i].draw();
	}
	
	for (i=0; i <= game->indexOfLastGun; i++)
	{
		game->gun[i].draw();
	}
	
	game->destroyers.draw();
}

void sb_Phase_PlaceGuns::drawTimer()
{
	glAAFlush();
	glLoadIdentity();
	glBindTexture(GL_TEXTURE_2D, glAA_texture[0]);
	vf_setpenscale(3.5f, 3.5f);
	vf_setpenloc( 10.0f, 690.0f );
	glAALineWidth(3);
	glAAColor4f(1.0f, 1.0f, 1.0f, 0.5f);
	if (secondsLeft >= 10)
	{
		vecString("%d", secondsLeft);
	}
	else
	{
		vecString("0%d", secondsLeft);
	}
}

void sb_Phase_PlaceGuns::drawRemainingGuns()
{
	float rgX, rgY;
	float originalX, originalY;
	
	originalX = game->gun[indexOfGunPointer].getX();
	originalY = game->gun[indexOfGunPointer].getY();
	
	rgX = 120;
	rgY = 716;
	
	int i;
	for (i=newGuns; i > 0; i--)
	{
		game->gun[indexOfGunPointer].moveTo(rgX, rgY);
		game->gun[indexOfGunPointer].draw();
		rgX += game->grid.getSectorSize()*2 + 5.0f;
	}
	
	game->gun[indexOfGunPointer].moveTo(originalX, originalY);
	
}

void sb_Phase_PlaceGuns::drawTitle()
{
	vf_setpentrack(8.0f, 0.0f);
	if (titleGlow > 0.0f)
	{	
		glAAFlush();
		glLoadIdentity();
		glBindTexture(GL_TEXTURE_2D, glAA_texture[2]);
		vf_setpenscale(titleScaleX, titleScaleY);
		vf_setpenloc( titleX, titleY );
		glAALineWidth(10);
		glAAColor4f(1.0f, 1.0f, 1.0f, titleGlow);
		vecString("DEPLOY WEAPONS");
	}
	
	glAAFlush();
	glLoadIdentity();
	glBindTexture(GL_TEXTURE_2D, glAA_texture[0]);
	vf_setpenscale(titleScaleX, titleScaleY);
	vf_setpenloc( titleX, titleY );
	glAALineWidth(3);
	glAAColor4f(1.0f, 1.0f, 1.0f, titleAlpha);
	vecString("DEPLOY WEAPONS");
}

void sb_Phase_PlaceGuns::drawPointer()
{
	game->gun[indexOfGunPointer].drawSquareInGrid();
	game->gun[indexOfGunPointer].draw();
}