//Copyright (c) 2004 Aaron Sullivan. All rights reserved.
#include "sb_Phase_PlaceShields.h"
#include "iostream.h"
#include "sb_Barge.h"

sb_Phase_PlaceShields::sb_Phase_PlaceShields( sb_GamePtr gameToUse) 
: sb_GamePhase( gameToUse ) //call sb_GamePhase constructor
{
	game = gameToUse;
	
	section.init(&game->grid);
	sectionNext.init(&game->grid);
	
	gameUtil.init(game);
	
	totalSeconds = 20;
	
	reset();
}

sb_Phase_PlaceShields::~sb_Phase_PlaceShields()
{
	
}

void sb_Phase_PlaceShields::start()
{
	done = false;
	time = 0;
	secondsLeft = totalSeconds;
	
	//title variables
	titleX = 12.0f, titleY = 745.0f;
	titleAlpha = 0.8f;
	titleScaleX = 10.0f;
	titleScaleY = 2.0f;
	titleGlow = 0.0f;

	gameUtil.testForEnclosures();
	
	game->musicBox.play(kMusic_countdown);

	//start keeping track of Ticks passed
	game->updateTicksPassed();
}

void sb_Phase_PlaceShields::pause()
{
	game->musicBox.pauseToggle();
}

void sb_Phase_PlaceShields::end()
{
	done = true;
	game->musicBox.stop();
}

void sb_Phase_PlaceShields::reset()
{
	section.move(0,0);
	section.reshape(game->rng.generate(0,10));
	
	sectionNext.setColor(1.0f, 1.0f, 1.0f, 0.5f);
	sectionNext.move(120,716);
	nextShape = game->rng.generate(0,10);
	sectionNext.reshape(nextShape);
}

void sb_Phase_PlaceShields::processEvent( SDL_Event &event )
{
	switch (event.type)
	{
		//pointer position comes from game object ( which has its own processEvent function )
		case SDL_MOUSEBUTTONDOWN:
			//try to drop the shield and if it does set up new pieces
			if (event.button.button == SDL_BUTTON_LEFT)
			{
				if (section.fitIntoGrid())
				{
					game->noisemaker.play(kFX_shieldSection);
					section.reshape(nextShape);
					nextShape = game->rng.generate(0,10);
					sectionNext.reshape(nextShape);
					int numberOfEnclosuresBefore = game->totalEnclosures;
					gameUtil.testForEnclosures();
					if (game->totalEnclosures > numberOfEnclosuresBefore)
					{
						game->noisemaker.play(kFX_shieldBarrier);
					}
				}
				else
				{
					game->noisemaker.play(kFX_buzz);
				}
			}
			if (event.button.button == SDL_BUTTON_RIGHT)
			{
				section.rotate();
			}
	
			break;
		case SDL_MOUSEBUTTONUP:
			break;
		case SDL_KEYDOWN:
			//spacebar rotates piece
			if (event.key.keysym.sym == SDLK_SPACE)
			{
				section.rotate();
			}
			//'F' fades out music
			if (event.key.keysym.sym == SDLK_f)
			{
				game->musicBox.fadeOut();
			}
			//'M' toggles music on and off
			if (event.key.keysym.sym==SDLK_m)
			{
				if(game->musicBox.isPlaying())
				{
					game->musicBox.stop();
				}
				else
				{
					game->musicBox.play();
				}
			}
			break;
		case SDL_KEYUP:
			break;
		default:
			break;
	}
}

void sb_Phase_PlaceShields::animate()
{
	Uint32 ticksPassed;
	game->updateTicksPassed();
	ticksPassed = game->getTicksPassed();
	
	section.move( game->pointerX, game->pointerY );
	section.animate( ticksPassed ); // use time to determine all animation so it's framerate independent
	
	int i;
	for (i=0; i <= game->indexOfLastGun; i++)
	{
		game->gun[i].animate( ticksPassed ); 
	}
	
	
//Time based events
	time = time + ticksPassed;
	
	Uint32 startTime, endTime;
	float transitionTime; //will hold amount 
	
  //animate the title of the phase
   //"stretch in"
	startTime = 0; endTime = 500; transitionTime = (float)(endTime - startTime - 1);
	if (time > startTime && time < endTime)
	{
		//the total amount to change (over whole time) is divided total time of transition and multiplied by how many ticks passed 
		//then that portion (which is the fraction needed for THIS update) is subtracted from the current value
		titleScaleX -= 9.0f/transitionTime*ticksPassed;
	}
	if (time > endTime) titleScaleX = 1.0f; //take care of inaccuracy of method
	
   //glow the title
	startTime = 500; endTime = 1000; transitionTime = (float)(endTime - startTime - 1);
	if (time > startTime && time < endTime)
	{
		if (titleGlow == 0.0f)
		{
			titleGlow = 1.0f;
		}
		titleGlow -= 1.0/transitionTime*ticksPassed;
	}
	if (time > endTime) titleGlow = 0.0f;
	
   //raise and vanish title
	startTime = 2000; endTime = 2500; transitionTime = (float)(endTime - startTime - 1);
	if (time > startTime && time < endTime)
	{
		titleY -= 100.0f/transitionTime*ticksPassed; 
		titleAlpha -= 0.8f/transitionTime*ticksPassed;
		if (titleAlpha < 0.0f) titleAlpha = 0.0f;
		titleScaleY += 10.0f/transitionTime*ticksPassed;
	}
	if (time > endTime) {
		titleY = 0.0;
		titleAlpha = 0.0f;
		titleScaleY = 4.0f;
	}
	
  //timer
   //*this phase is ended when the timer (secondsLeft) runs out
	secondsLeft = totalSeconds - time/1000; //time/1000 turns milliseconds into seconds
	if (secondsLeft < 0)
	{
		secondsLeft = 0;
		end(); //end this phase
		
	}
}

void sb_Phase_PlaceShields::draw()
{
	glMatrixMode(GL_MODELVIEW); //we select the Model matrix to do our drawing
	
	drawTitle();
	drawTimer();

	glBindTexture(GL_TEXTURE_2D, glAA_texture[0]);
	game->grid.displayGrid(game->pointerX, game->pointerY, 100);
	
	game->grid.displayShields();
	
	section.displayInGrid();
	sectionNext.display();
	
	int i;
	for (i=0; i<game->totalBarges; i++)
	{
		game->barge[i].draw();
	}
	
	for (i=0; i <= game->indexOfLastGun; i++) //-1 because the last gun is the pointer
	{
		game->gun[i].draw();
	}
	
	game->destroyers.draw();
}

void sb_Phase_PlaceShields::drawTimer()
{
	glAAFlush();
	glLoadIdentity();
	glBindTexture(GL_TEXTURE_2D, glAA_texture[0]);
	vf_setpenscale(3.5f, 3.5f);
	vf_setpenloc( 10.0f, 690.0f );
	glAALineWidth(3);
	glAAColor4f(1.0f, 1.0f, 1.0f, 0.5f);
	if (secondsLeft >= 10)
	{
		vecString("%d", secondsLeft);
	}
	else
	{
		vecString("0%d", secondsLeft);
	}
}

void sb_Phase_PlaceShields::drawTitle()
{
	vf_setpentrack(8.0f, 0.0f);
	if (titleGlow > 0.0f)
	{	
		glAAFlush();
		glLoadIdentity();
		glBindTexture(GL_TEXTURE_2D, glAA_texture[2]);
		vf_setpenscale(titleScaleX, titleScaleY);
		vf_setpenloc( titleX, titleY );
		glAALineWidth(10);
		glAAColor4f(1.0f, 1.0f, 1.0f, titleGlow);
		vecString("REPAIR SHIELDS");
	}
	
	glAAFlush();
	glLoadIdentity();
	glBindTexture(GL_TEXTURE_2D, glAA_texture[0]);
	vf_setpenscale(titleScaleX, titleScaleY);
	vf_setpenloc( titleX, titleY );
	glAALineWidth(3);
	glAAColor4f(1.0f, 1.0f, 1.0f, titleAlpha);
	vecString("REPAIR SHIELDS");
}