//Copyright (c) 2004 Aaron Sullivan. All rights reserved.
#include "sb_Phase_SetStage.h"
#include "iostream.h"
#include "sb_Barge.h"

sb_Phase_SetStage::sb_Phase_SetStage( sb_GamePtr gameToUse) 
: sb_GamePhase( gameToUse ) //call sb_GamePhase constructor
{
	game = gameToUse;
	
	reset();
}

sb_Phase_SetStage::~sb_Phase_SetStage()
{
	
}

void sb_Phase_SetStage::start()
{
	done = false;
	time = 0;
	secondsLeft = totalSeconds;
	
	//title variables
	titleX = 12.0f, titleY = 745.0f;
	titleAlpha = 0.8f;
	titleScaleX = 10.0f;
	titleScaleY = 2.0f;
	titleGlow = 0.0f;
	
	//phase specific
	waitingForChoice = false;
	bargesShowing = 0;
	enemyShowing = false;
	shieldsBuilding = false;
	chosenBarge = 0;
	shieldRow = 0;
	
	game->currentWave = 1;
	initStage();
	
	//start keeping track of Ticks passed
	game->updateTicksPassed();
}

void sb_Phase_SetStage::pause()
{
	game->musicBox.pauseToggle();
}

void sb_Phase_SetStage::end()
{
	done = true;
}

void sb_Phase_SetStage::reset()
{
	totalSeconds = 10;
}

void sb_Phase_SetStage::processEvent( SDL_Event &event )
{
	int i;
	switch (event.type)
	{
		//pointer position comes from game object ( which has its own processEvent function )
		case SDL_MOUSEBUTTONDOWN:
			if (waitingForChoice)
			{
				for (i=0; i < game->totalBarges; i++)
				{
					//if the player clicks in a barge
					if (game->barge[i].pointIsInBarge((float)game->pointerX, (float)game->pointerY))
					{
						//put the shields up around the chosen barge... and eventually end the phase
						chosenBarge = i;
						waitingForChoice = false;
						shieldsBuilding = true;
						shieldRow = 0; //number of shields added starts at none
						timeChoiceEnded = time;
					}
				}
				
			}
			
			// make set up animation skipable
			else if(time > 200)
			{
				waitingForChoice = true;
				timeChoiceStarted = time;
				bargesShowing = 5;
				enemyShowing = true;
			}
			break;
		case SDL_MOUSEBUTTONUP:
			break;
		case SDL_KEYDOWN:
			if (event.key.keysym.sym == SDLK_SPACE)
			{
				//skip animated intro? 
			}
			//'F' fades out music
			if (event.key.keysym.sym == SDLK_f)
			{
				game->musicBox.fadeOut();
			}
			//'M' toggles music on and off
			if (event.key.keysym.sym==SDLK_m)
			{
				if(game->musicBox.isPlaying())
				{
					game->musicBox.stop();
				}
				else
				{
					game->musicBox.play();
				}
			}
			break;
		case SDL_KEYUP:
			break;
		default:
			break;
	}
}

void sb_Phase_SetStage::animate()
{
	int i;
	Uint32 ticksPassed;
	game->updateTicksPassed();
	ticksPassed = game->getTicksPassed();
	
	//Time based events
	time = time + ticksPassed;
	
	Uint32 startTime, endTime;
	float transitionTime; //will hold amount 
	
	if (time > 500 && bargesShowing == 0)
	{
		bargesShowing = 1;
		game->noisemaker.play(kFX_tactical1);
	}
	if (time > 1500 && bargesShowing == 1)
	{
		bargesShowing = 2;
		game->noisemaker.play(kFX_tactical1);
	}
	if (time > 2500 && bargesShowing == 2)
	{
		bargesShowing = 3;
		game->noisemaker.play(kFX_tactical1);
	}
	if (time > 3500 && bargesShowing == 3)
	{
		bargesShowing = 4;
		game->noisemaker.play(kFX_tactical2);
	}
	if (time > 4500 && bargesShowing == 4)
	{
		bargesShowing = 5;
		game->noisemaker.play(kFX_tactical3);
	}
	
	if (time > 6000 && bargesShowing == 5 && !enemyShowing)
	{
		enemyShowing = true;
		game->noisemaker.play(kFX_tactical4);
	}
	
	if (time > 6500 && enemyShowing == true && shieldsBuilding == false)
	{
		waitingForChoice = true;
		timeChoiceStarted = 6500;
	}
	
	if (waitingForChoice)
	{
		//animate the title of the phase
		//"stretch in"
		startTime = timeChoiceStarted; endTime = timeChoiceStarted+500; transitionTime = (float)(endTime - startTime - 1);
		if (time > startTime && time < endTime)
		{
			//the total amount to change (over whole time) is divided total time of transition and multiplied by how many ticks passed 
			//then that portion (which is the fraction needed for THIS update) is subtracted from the current value
			titleScaleX -= 9.0f/transitionTime*ticksPassed;
		}
		if (time > endTime) titleScaleX = 1.0f; //take care of inaccuracy of method
		
		//glow the title
		startTime = timeChoiceStarted+500; endTime = timeChoiceStarted+1000; transitionTime = (float)(endTime - startTime - 1);
		if (time > startTime && time < endTime)
		{
			if (titleGlow == 0.0f)
			{
				titleGlow = 1.0f;
			}
			titleGlow -= 1.0/transitionTime*ticksPassed;
		}
		if (time > endTime) titleGlow = 0.0f;
		
		//raise and vanish title
		startTime = timeChoiceStarted+2500; endTime = timeChoiceStarted+3000; transitionTime = (float)(endTime - startTime - 1);
		if (time > startTime && time < endTime)
		{
			titleY -= 100.0f/transitionTime*ticksPassed; 
			titleAlpha -= 0.8f/transitionTime*ticksPassed;
			if (titleAlpha < 0.0f) titleAlpha = 0.0f;
			titleScaleY += 10.0f/transitionTime*ticksPassed;
		}
		if (time > endTime) {
			titleY = 0.0;
			titleAlpha = 0.0f;
			titleScaleY = 4.0f;
		}
		
		//timer
		//*this phase is ended when the timer (secondsLeft) runs out
		secondsLeft = totalSeconds - (time-timeChoiceStarted)/1000; //time/1000 turns milliseconds into seconds
		if (secondsLeft < 0)
		{
			secondsLeft = 0;
			chosenBarge = game->rng.generate(0,game->totalBarges-1);
			waitingForChoice = false;
			shieldsBuilding = true;
			shieldRow = 0; //number of shields added starts at none
			timeChoiceEnded = time;
		}
	}
	
	if (shieldsBuilding)
	{
		if (time > timeChoiceEnded && shieldRow == 0)
		{   
			float xDot, yDot;
			xDot = game->barge[chosenBarge].getX() - (game->grid.getSectorSize() * 3) - 1;
			yDot = game->barge[chosenBarge].getY() - (game->grid.getSectorSize() * 3) - 1;
			shieldCorner = game->grid.sectorPointOnDot((int)xDot, (int)yDot);
			for (i=0; i < 8; i++)
			{
				game->grid.setSector((int)shieldCorner.x + i, (int)shieldCorner.y, kST_shield);
			}
			game->noisemaker.play(kFX_shieldSection);
			shieldRow = 1;
		}
		if (time > timeChoiceEnded+300 && shieldRow == 1)
		{
			game->grid.setSector((int)shieldCorner.x, (int)shieldCorner.y+1, kST_shield);
			game->grid.setSector((int)shieldCorner.x+7, (int)shieldCorner.y+1, kST_shield);
			game->grid.setSector((int)shieldCorner.x, (int)shieldCorner.y+2, kST_shield);
			game->grid.setSector((int)shieldCorner.x+7, (int)shieldCorner.y+2, kST_shield);
			game->noisemaker.play(kFX_shieldSection);
			shieldRow = 3;
		}
		if (time > timeChoiceEnded+600 && shieldRow == 3)
		{
			game->grid.setSector((int)shieldCorner.x, (int)shieldCorner.y+3, kST_shield);
			game->grid.setSector((int)shieldCorner.x+7, (int)shieldCorner.y+3, kST_shield);
			game->grid.setSector((int)shieldCorner.x, (int)shieldCorner.y+4, kST_shield);
			game->grid.setSector((int)shieldCorner.x+7, (int)shieldCorner.y+4, kST_shield);
			game->noisemaker.play(kFX_shieldSection);
			shieldRow = 5;
		}
		if (time > timeChoiceEnded+900 && shieldRow == 5)
		{
			game->grid.setSector((int)shieldCorner.x, (int)shieldCorner.y+5, kST_shield);
			game->grid.setSector((int)shieldCorner.x+7, (int)shieldCorner.y+5, kST_shield);
			game->grid.setSector((int)shieldCorner.x, (int)shieldCorner.y+6, kST_shield);
			game->grid.setSector((int)shieldCorner.x+7, (int)shieldCorner.y+6, kST_shield);
			game->noisemaker.play(kFX_shieldSection);
			shieldRow = 7;
		}
		if (time > timeChoiceEnded+1300 && shieldRow == 7) //tiny delay before last shield for impact
		{
			for (i=0; i < 8; i++)
			{
				game->grid.setSector((int)shieldCorner.x + i, (int)shieldCorner.y+7, kST_shield);
			}
			game->noisemaker.play(kFX_shieldSection);
			game->noisemaker.play(kFX_shieldBarrier);
			game->grid.testForClosure();
			game->totalEnclosures = 1;
			game->barge[chosenBarge].makeActive();
			shieldRow = 8;
		}
		if (time > timeChoiceEnded+1800 && shieldRow == 8) 
		{
			end();
		}
	}
}

void sb_Phase_SetStage::draw()
{
	glMatrixMode(GL_MODELVIEW); //we select the Model matrix to do our drawing
	
	if (waitingForChoice)
	{
		drawTitle();
		drawTimer();
		drawPointer();
	}

	glBindTexture(GL_TEXTURE_2D, glAA_texture[0]);
	
	
	if (shieldsBuilding)
	{
		game->grid.displayGrid(game->barge[chosenBarge].getX(), game->barge[chosenBarge].getY(), 100);
	}
	
	if (enemyShowing || waitingForChoice || shieldsBuilding)
	{
		game->grid.displayShields();
	}
	
	if (enemyShowing)
	{
		game->destroyers.draw();
	}

	
	int i;
	for (i=0; i < bargesShowing; i++)
	{
		game->barge[i].draw();
	}
}

void sb_Phase_SetStage::drawTimer()
{
	glAAFlush();
	glLoadIdentity();
	glBindTexture(GL_TEXTURE_2D, glAA_texture[0]);
	vf_setpenscale(3.5f, 3.5f);
	vf_setpenloc( 10.0f, 690.0f );
	glAALineWidth(3);
	glAAColor4f(1.0f, 1.0f, 1.0f, 0.5f);
	if (secondsLeft >= 10)
	{
		vecString("%d", secondsLeft);
	}
	else
	{
		vecString("0%d", secondsLeft);
	}
}

void sb_Phase_SetStage::drawTitle()
{
	vf_setpentrack(8.0f, 0.0f);
	if (titleGlow > 0.0f)
	{	
		glAAFlush();
		glLoadIdentity();
		glBindTexture(GL_TEXTURE_2D, glAA_texture[2]);
		vf_setpenscale(titleScaleX, titleScaleY);
		vf_setpenloc( titleX, titleY );
		glAALineWidth(10);
		glAAColor4f(1.0f, 1.0f, 1.0f, titleGlow);
		vecString("STAGE %d WAVE %d", game->currentLevel, game->currentWave);
	}
	
	glAAFlush();
	glLoadIdentity();
	glBindTexture(GL_TEXTURE_2D, glAA_texture[0]);
	vf_setpenscale(titleScaleX, titleScaleY);
	vf_setpenloc( titleX, titleY );
	glAALineWidth(3);
	glAAColor4f(1.0f, 1.0f, 1.0f, titleAlpha);
	vecString("STAGE %d WAVE %d", game->currentLevel, game->currentWave);
}

void sb_Phase_SetStage::drawPointer()
{
	glAAFlush();
	glLoadIdentity();
	glTranslatef(game->pointerX, game->pointerY, 0.0f);
	glAALineWidth(2);
	glAAColor4f(1.0f, 1.0f, 0.0f, 0.6f);
	glAABegin(GL_LINE_STRIP);
	glAAVertex2f(0.0f,0.0f);
	glAAVertex2f(0.0f,15.0f);
	glAAVertex2f(4.0f,10.0f);
	glAAVertex2f(12.0f,12.0f);
	glAAVertex2f(0.0f,0.0f);
	glAAEnd();
	glAAColor4f(1.0f, 1.0f, 0.0f, 0.2f);
	
	//below code is for a streak after pointer...
	//something is screwy with the relative movement events so...
	/*
	float pointerRelX = (float)game->pointerRelX;
	float pointerRelY = (float)game->pointerRelY;
	
	glAABegin(GL_LINE_STRIP);
	glAAVertex2f(0.0f,0.0f);
	glAAVertex2f(0.0f - pointerRelX, 0.0f - pointerRelY);
	glAAEnd();
	glAABegin(GL_LINE_STRIP);
	glAAVertex2f(0.0f,15.0f);
	glAAVertex2f(0.0f - pointerRelX, 15.0f - pointerRelY);
	glAAEnd();
	glAABegin(GL_LINE_STRIP);
	glAAVertex2f(4.0f,10.0f);
	glAAVertex2f(4.0f - pointerRelX, 10.0f - pointerRelY);
	glAAEnd();
	glAABegin(GL_LINE_STRIP);
	glAAVertex2f(12.0f,12.0f);
	glAAVertex2f(12.0f - pointerRelX, 12.0f - pointerRelY);
	glAAEnd();
	 */
}

void sb_Phase_SetStage::initStage()
{
	int i;
	//*clear out grid
	//set grid to all outOfRange... we will fill in the area with vacant spots for the player
	for (i=0; i<game->grid.totalSectors; i++)
	{
		game->grid.setSector( i, kST_outOfRange );
	}
	
	//*establish basic layout ( us side and them side )
	//randomly select a stageLayout
	if (game->currentLevel == 1)
	{
		//only use first two because they give maximum distance between player and enemy
		game->stageLayout = game->rng.generate(1,2);
	}
	else if (game->currentLevel == 2)
	{
		//allow the possibility of top to bottom levels 
		game->stageLayout = game->rng.generate(1,4);
	}
	else
	{
		//now allow the possibility of the nasty diagonals where the enemy can start
		//relatively close to the border
		game->stageLayout = game->rng.generate(1,8);
	}

	int ix, iy;
	int startX, startY, endX, endY, changeInStart, changeInEnd;
	int xSectors = game->grid.xSectors; //these are purely for code clarity
	int ySectors = game->grid.ySectors;
	
	//assign variables for correct fill-in of vacant sectors ( the "us" side )
	switch (game->stageLayout)
	{
		case 1: // us|them
			startX = 0;  endX = xSectors/2 - 5;
			startY = 0;  endY = ySectors - 1;
			changeInStart = 0; changeInEnd = 0;
			//also set the vector so the enemies know which way to approach
			game->enemyAdvanceVector.dx = -1.0f;
			game->enemyAdvanceVector.dy = 0.0f;
			//also set up the side of the screen where the enemies will approach from
			game->enemyBorder.begin.x = game->grid.getXRes()-32.0f;
			game->enemyBorder.end.x =  game->grid.getXRes()-32.0f;
			game->enemyBorder.begin.y = 0.0f;
			game->enemyBorder.end.y = game->grid.getYRes()-32.0f;
			break;
		case 2: // them|us
			startX = xSectors/2 + 5;  endX = xSectors-1;
			startY = 0;  endY = ySectors - 1;
			changeInStart = 0; changeInEnd = 0;
			game->enemyAdvanceVector.dx = 1.0f;
			game->enemyAdvanceVector.dy = 0.0f;
			game->enemyBorder.begin.x = 0.0f;
			game->enemyBorder.end.x =  0.0f;
			game->enemyBorder.begin.y = 0.0f;
			game->enemyBorder.end.y = game->grid.getYRes()-32.0f;
			break;
		case 3: // us above them
			startX = 0;  endX = xSectors - 1;
			startY = 0;  endY = ySectors/2 - 3;
			changeInStart = 0; changeInEnd = 0;
			game->enemyAdvanceVector.dx = 0.0f;
			game->enemyAdvanceVector.dy = -1.0f;
			game->enemyBorder.begin.x = 0.0f;
			game->enemyBorder.end.x =  game->grid.getXRes()-32.0f;
			game->enemyBorder.begin.y = game->grid.getYRes()-32.0f;
			game->enemyBorder.end.y = game->grid.getYRes()-32.0f;
			break;
		case 4: // them above us
			startX = 0;  endX = xSectors - 1;
			startY = ySectors/2 + 3;  endY = ySectors - 1;
			changeInStart = 0; changeInEnd = 0;
			game->enemyAdvanceVector.dx = 0.0f;
			game->enemyAdvanceVector.dy = 1.0f;
			game->enemyBorder.begin.x = 0.0f;
			game->enemyBorder.end.x =  game->grid.getXRes()-32.0f;
			game->enemyBorder.begin.y = 0.0f;
			game->enemyBorder.end.y = 0.0f;
			break;
		case 5: // us/them
			startX = 0;  endX = xSectors - 17;
			startY = 0;  endY = ySectors - 1;
			changeInStart = 0; changeInEnd = -1;
			game->enemyAdvanceVector.dx = -1.0f;
			game->enemyAdvanceVector.dy = -1.0f;
			game->enemyBorder.begin.x = game->grid.getXRes()-32.0f;
			game->enemyBorder.end.x =  game->grid.getXRes()-32.0f;
			game->enemyBorder.begin.y = 0.0f;
			game->enemyBorder.end.y = game->grid.getYRes()-32.0f;
			break;
		case 6: // them/us
			startX = xSectors - 2;  endX = xSectors - 1;
			startY = 0;  endY = ySectors - 1;
			changeInStart = -1; changeInEnd = 0;
			game->enemyAdvanceVector.dx = 1.0f;
			game->enemyAdvanceVector.dy = 1.0f;
			game->enemyBorder.begin.x = 0.0f;
			game->enemyBorder.end.x =  0.0f;
			game->enemyBorder.begin.y = 0.0f;
			game->enemyBorder.end.y = game->grid.getYRes()-32.0f;
			break;
		case 7: // us\them
			startX = 0;  endX = 1;
			startY = 0;  endY = ySectors - 1;
			changeInStart = 0; changeInEnd = +1;
			game->enemyAdvanceVector.dx = -1.0f;
			game->enemyAdvanceVector.dy = 1.0f;
			game->enemyBorder.begin.x = game->grid.getXRes()-32.0f;
			game->enemyBorder.end.x =  game->grid.getXRes()-32.0f;
			game->enemyBorder.begin.y = 0.0f;
			game->enemyBorder.end.y = game->grid.getYRes()-32.0f;
			break;
		case 8: // them\us
			startX = 12;  endX = xSectors - 1;
			startY = 0;  endY = ySectors - 1;
			changeInStart = +1; changeInEnd = 0;
			game->enemyAdvanceVector.dx = 1.0f;
			game->enemyAdvanceVector.dy = -1.0f;
			game->enemyBorder.begin.x = 0.0f;
			game->enemyBorder.end.x =  0.0f;
			game->enemyBorder.begin.y = 0.0f;
			game->enemyBorder.end.y = game->grid.getYRes()-32.0f;
			break;
	}
	
	//launch initial destroyers (enemy ships)
	game->destroyers.reset();
	game->destroyers.init(game->enemyBorder, game->enemyAdvanceVector, &game->grid ); //very necessary!
	int numberOfEnemiesToLaunch = (int)((20 + game->currentLevel * (CLAMP(game->currentLevel/4, 1, 200))) * 0.2f); //first wave is 20% of total
	game->destroyers.launch(numberOfEnemiesToLaunch);
	
	//use chosen settings to fill in vacant sectors
	for (iy = startY; iy <= endY; iy++)
	{
		for (ix = startX; ix <= endX; ix++)
		{
			game->grid.setSector(ix, iy, kST_vacant );
		}
		startX += changeInStart;
		endX += changeInEnd;
	}
	
	//*place barges
	//choose direction for all barges to face
	float rotation = game->rng.generate(0,359);
	for (i=0; i < game->totalBarges; i++)
	{
		game->barge[i].setRotation(rotation);
		game->barge[i].makeInactive(); //so it doesn't retain settings from previous stage
	}
	
	
	float xAttempt, yAttempt;
	int triesBeforeGivingUp; //used for the unlikely occurence that it's impossible to fit the last one or two barges
	for (i=0; i < game->totalBarges; i++ )
	{
		triesBeforeGivingUp = 1000;
		do
		{
			xAttempt = (float)game->rng.generate(0,game->grid.getXRes());
			yAttempt = (float)game->rng.generate(0,game->grid.getYRes());
			triesBeforeGivingUp--;
		} while (! game->barge[i].fitIntoGrid(xAttempt, yAttempt) && (triesBeforeGivingUp > 0));
	}
	
	//*reset guns
	for (i=0; i < game->totalGuns; i++)
	{
		//do stuff to each gun
	}
	game->indexOfLastGun = -1; 
	
}