//Copyright (c) 2004 Aaron Sullivan. All rights reserved.
#include "sb_ShieldGrid.h"
#include <iostream.h>

sb_ShieldGrid::sb_ShieldGrid()
{
	xRes = 1024;
	yRes = 768;
	sectorSize = 16;
	xSectors = xRes/sectorSize;
	ySectors = yRes/sectorSize;
	totalSectors = xSectors * ySectors; //3072 (for 1024x768)
	
	int i;
	for (i = 0; i < totalSectors; i++)
	{
		sector[i] = kST_vacant;
	}
	
	int x, y;
	for (y=0; y < ySectors; y++)
	{
		for (x=0; x < xSectors; x++)
		{
			outside[x][y] = true; //every square is "outside" to begin with
		}
	}
	
	//set up an array of predetermined random offsets, so we don't have to calculate them each later.
	rng.init();
	for (i=0; i < 500; i++)
	{
		RandomSparkleOffset[i] = (float)(rng.generate(0, sectorSize))-(float)sectorSize/2;
	}
	rsoIndex = 0;
	
	setColor(0.2f, 0.4f, 1.0f, 0.8f);
}

sb_ShieldGrid::~sb_ShieldGrid()
{
	
}

void sb_ShieldGrid::reset()
{
	xRes = 1024;
	yRes = 768;
	sectorSize = 16;
	xSectors = xRes/sectorSize;
	ySectors = yRes/sectorSize;
	totalSectors = xSectors * ySectors; //3072 (for 1024x768)
	
	int i;
	for (i = 0; i < totalSectors; i++)
	{
		sector[i] = kST_vacant;
	}
	
	int x, y;
	for (y=0; y < ySectors; y++)
	{
		for (x=0; x < xSectors; x++)
		{
			outside[x][y] = true; //every square is "outside" to begin with
		}
	}
	
	setColor(0.2f, 0.4f, 1.0f, 0.8f);
}

void sb_ShieldGrid::setColor(float red, float green, float blue, float alpha)
{
	r = CLAMP(red, 0.0f, 1.0f);
	g = CLAMP(green, 0.0f, 1.0f);
	b = CLAMP(blue, 0.0f, 1.0f);
	a = CLAMP(alpha, 0.0f, 1.0f);
}

void sb_ShieldGrid::displayGrid()
{
    
    int gridx, gridy;
    
    glAAColor4f(0.0f, 0.0f, 1.0f, 0.4f);
    glAALineWidth(1);
    
	glAAFlush();
    glLoadIdentity();
    
    for (gridx = 0; gridx <= xRes; gridx += sectorSize)
    {
            glAABegin(GL_LINE_STRIP);
            glAAVertex2f((float)gridx, 0.0f);
            glAAVertex2f((float)gridx, (float)yRes);
            glAAEnd();
    }
    for (gridy = 0; gridy <= yRes; gridy += sectorSize)
    {
            glAABegin(GL_LINE_STRIP);
            glAAVertex2f(0.0f, (float)gridy);
            glAAVertex2f((float)xRes, (float)gridy);
            glAAEnd();
    }
}

void sb_ShieldGrid::displayGrid(float centerX, float centerY, int area)
{
	float top, bottom, left, right;
	float alpha = 1.0f;
	
	centerX = (int)centerX;
	centerY = (int)centerY;
	
	//determine the bounds of the area we will display from the grid
	left = CLAMP(centerX-area, 0, xRes); //CLAMP is a macro defined in AAPrimitives.h to deal with keeping a number between a high and low
	right = CLAMP(centerX+area, 0, xRes);
	top = CLAMP(centerY-area, 0, yRes);
	bottom = CLAMP(centerY+area, 0, yRes);
	
	if (top==bottom || left==right) return; //our values are way outside of the bounds and there's nothing to display
	

	//now we draw just the gridlines that are at every 16 pixels starting with verticle lines
	glAAFlush();
    glLoadIdentity();
	glAALineWidth(1);
	
	alpha = 1.0f;
	float alphaChange = alpha/(area/16);
	float gridX;
	for (gridX = centerX+1; gridX < right; gridX++)
	{
		if ((int)gridX % sectorSize == 0)
		{
			//draw from middle up and fade to transparent
			glAABegin(GL_LINE_STRIP);
			glAAColor4f(0.0f, 0.0f, 1.0f, alpha);
			glAAVertex2f(gridX, centerY);
			glAAColor4f(0.0f, 0.0f, 1.0f, 0.0f);
			glAAVertex2f(gridX, top);
			glAAEnd();
			
			//draw from middle down and fade transparent
			glAABegin(GL_LINE_STRIP);
			glAAColor4f(0.0f, 0.0f, 1.0f, alpha);
			glAAVertex2f(gridX, centerY+0.5f);
			glAAColor4f(0.0f, 0.0f, 1.0f, 0.0f);
			glAAVertex2f(gridX, bottom);
			glAAEnd();
			
			alpha -= alphaChange;
		}
	}
	
	alpha = 1.0f;
	for (gridX = centerX; gridX > left; gridX--)
	{
		if ((int)gridX % sectorSize == 0)
		{
			//draw from middle up and fade to transparent
			glAABegin(GL_LINE_STRIP);
			glAAColor4f(0.0f, 0.0f, 1.0f, alpha);
			glAAVertex2f(gridX, centerY);
			glAAColor4f(0.0f, 0.0f, 1.0f, 0.0f);
			glAAVertex2f(gridX, top);
			glAAEnd();
			
			//draw from middle down and fade transparent
			glAABegin(GL_LINE_STRIP);
			glAAColor4f(0.0f, 0.0f, 1.0f, alpha);
			glAAVertex2f(gridX, centerY+0.5f);
			glAAColor4f(0.0f, 0.0f, 1.0f, 0.0f);
			glAAVertex2f(gridX, bottom);
			glAAEnd();
			
			alpha -= alphaChange;
		}
	}
	
	alpha = 1.0f;
	float gridY;
	for (gridY = centerY+1; gridY < bottom; gridY++)
	{
		if ((int)gridY % sectorSize == 0)
		{
			//draw from middle to the left and fade to transparent
			glAABegin(GL_LINE_STRIP);
			glAAColor4f(0.0f, 0.0f, 1.0f, alpha);
			glAAVertex2f(centerX, gridY);
			glAAColor4f(0.0f, 0.0f, 1.0f, 0.0f);
			glAAVertex2f(left, gridY);
			glAAEnd();
			
			//draw from middle down and fade transparent
			glAABegin(GL_LINE_STRIP);
			glAAColor4f(0.0f, 0.0f, 1.0f, alpha);
			glAAVertex2f(centerX+0.5f, gridY);
			glAAColor4f(0.0f, 0.0f, 1.0f, 0.0f);
			glAAVertex2f( right , gridY);
			glAAEnd();
			
			alpha -= alphaChange;
		}
	}
	
	alpha = 1.0f;
	for (gridY = centerY; gridY > top; gridY--)
	{
		if ((int)gridY % sectorSize == 0)
		{
			//draw from middle to the left and fade to transparent
			glAABegin(GL_LINE_STRIP);
			glAAColor4f(0.0f, 0.0f, 1.0f, alpha);
			glAAVertex2f(centerX, gridY);
			glAAColor4f(0.0f, 0.0f, 1.0f, 0.0f);
			glAAVertex2f(left, gridY);
			glAAEnd();
			
			//draw from middle down and fade transparent
			glAABegin(GL_LINE_STRIP);
			glAAColor4f(0.0f, 0.0f, 1.0f, alpha);
			glAAVertex2f(centerX+0.5f, gridY);
			glAAColor4f(0.0f, 0.0f, 1.0f, 0.0f);
			glAAVertex2f( right , gridY);
			glAAEnd();
			
			alpha -= alphaChange;
		}
	}
}

void sb_ShieldGrid::displayShields()
{
	int i;
	float x, y;
	int ix, iy;
	
	float halfSector = sectorSize/2;
	
	x = halfSector;
	y = halfSector;
	
	glAAFlush();
	glLoadIdentity(); //reset coordinates
	
	//*shields
	//draw "sparkley" points inside each square that is a shieldsector
	glAAPointSize(3.0f);
	glAAColor4f(0.3f, 0.3f, 1.0f, CLAMP(a+0.3f,0.0f,1.0f));

	glAABegin(GL_POINTS);

	for (i=0; i < totalSectors; i++)
	{
		if (sector[i] == kST_shield)
		{
			glAAVertex2f( x+ getRandomSparkleOffset(), y + getRandomSparkleOffset());
		}
		x += sectorSize;
		if(x > xRes)
		{
			x = 0 + halfSector;
			y += sectorSize;
		}
	}
	glAAEnd();	
	
	//*insideShield - draw pattern to show area that is inside shields
	x = halfSector;
	y = halfSector;
	
	glAALineWidth(1.0f);
	glAAColor4f(CLAMP(r-0.3f,0.0f,1.0f), CLAMP(g-0.3f,0.0f,1.0f), 1.0f, CLAMP(a-0.3f,0.0f,1.0f));
	

	for (i=0; i < totalSectors; i++)
	{
		if (sector[i] == kST_insideShield)
		{
			glAABegin(GL_LINE_STRIP );
			glAAVertex2f( x-halfSector, y-halfSector );
			glAAVertex2f(x+halfSector, y+halfSector);
			glAAEnd();	
		}
		x += sectorSize;
		if(x > xRes)
		{
			x = 0 + halfSector;
			y += sectorSize;
		}
	}
	
	//*barrier - draw barrier between vacant areas and out of range areas
	ix=0;
	iy=0;
	for (iy=0; iy < ySectors; iy++) //for all rows
	{
		for (ix=0; ix < xSectors-1; ix++) //for all columns eixcept for the last
		{
			//if this square is out of range and the neixt to the right isn't... or visa versa
			if ((getSectorValue(ix,iy) == kST_outOfRange && getSectorValue(ix+1,iy) != kST_outOfRange)
				|| (getSectorValue(ix,iy) != kST_outOfRange && getSectorValue(ix+1,iy) == kST_outOfRange))
			{
				//draw a vertical line on the right
				glAABegin(GL_LINE_STRIP);
				glAAVertex2f( ix*sectorSize + sectorSize, iy*sectorSize + 0.5);
				glAAVertex2f( ix*sectorSize + sectorSize, iy*sectorSize + sectorSize - 0.5);
				glAAEnd();
			}
			if (iy < ySectors-1) //as long as we aren't on the last row
			{
				//if this square is out of range and the neixt below isn't... or visa versa
				if ((getSectorValue(ix,iy) == kST_outOfRange && getSectorValue(ix,iy+1) != kST_outOfRange)
					|| (getSectorValue(ix,iy) != kST_outOfRange && getSectorValue(ix,iy+1) == kST_outOfRange))	
				{
					//draw a horizontal line below
					glAABegin(GL_LINE_STRIP);
					glAAVertex2f( ix*sectorSize +.05 , iy*sectorSize + sectorSize - 0.5);
					glAAVertex2f( ix*sectorSize + sectorSize - 0.5, iy*sectorSize + sectorSize - 0.5);
					glAAEnd();
				}
			}
			
		}
	}
	
	
	//*shields
	//draw top shield lines for squares that are "on" (not zero)
	x=0;
	glAALineWidth(2);
	glAAColor4f(r,g,b,a);

	for (i=0; i < xSectors; i++) //top row only
	{
		if (sector[i] == kST_shield)
		{
			glAABegin(GL_LINE_STRIP);
			glAAVertex2f( x +.05 , 0);
			glAAVertex2f( x + sectorSize - 0.5, 0);
			glAAEnd();
		}
		x += sectorSize;
	}
	
	x=0;
	y=0;
	for (i=0; i < totalSectors; i++) //loop through all lines
	{
		if (i % xSectors == 0) //if this is the left most square of this line
		{
			if (sector[i] == kST_shield)//if this square is on
			{
				//draw a vertical line on the left
				glAABegin(GL_LINE_STRIP);
				glAAVertex2f( x, y + 0.5);
				glAAVertex2f( x, y + sectorSize - 0.5);
				glAAEnd();
			}
		}
		
		if ((i+1) % xSectors == 0) //if this is the last square of this line
		{
			if (sector[i] == kST_shield)//if this square is on
			{
				//draw a vertical line on the right
				glAABegin(GL_LINE_STRIP);
				glAAVertex2f( x + sectorSize, y + 0.5);
				glAAVertex2f( x + sectorSize, y + sectorSize - 0.5);
				glAAEnd();
			}
		}
		else //do normal check to the right
		{
			//if the square to the right is on and this one is off... or visa versa
			if ((sector[i] == kST_shield && sector[i+1] != kST_shield) || (sector[i] != kST_shield && sector[i+1] == kST_shield))
			{
				//draw a vertical line on the right
				glAABegin(GL_LINE_STRIP);
				glAAVertex2f( x + sectorSize, y + 0.5);
				glAAVertex2f( x + sectorSize, y + sectorSize - 0.5);
				glAAEnd();
			}
		}
		
		if (i+xSectors >= totalSectors) //if we are on the bottom line
		{
			if (sector[i] == kST_shield) //if this square is "on"
			{
				//draw a horizontal line below
				glAABegin(GL_LINE_STRIP);
				glAAVertex2f( x +.05 , y + sectorSize - 0.5);
				glAAVertex2f( x + sectorSize - 0.5, y + sectorSize - 0.5);
				glAAEnd();
			}
		}
		else //do a normal check below
		{
			//if the square below is on and this one is off... or visa versa
			if ((sector[i] == kST_shield && sector[i+xSectors] != kST_shield ) || (sector[i] != kST_shield && sector[i+xSectors] == kST_shield))
			{
				//draw a horizontal line below
				glAABegin(GL_LINE_STRIP);
				glAAVertex2f( x +.05 , y + sectorSize - 0.5);
				glAAVertex2f( x + sectorSize - 0.5, y + sectorSize - 0.5);
				glAAEnd();
			}
		}
		x += sectorSize;
		if(x >= xRes)
		{
			x = 0;
			y += sectorSize;
		}
	}
}

void sb_ShieldGrid::setSector(int x, int y, sb_SectorType newValue)
{
	int sectorIndex;
	
	if (x < xSectors && y < ySectors && x > -1 && y > -1)
	{
		sectorIndex = xSectors*y + x;
		sector[sectorIndex] = newValue;
	}
}

void sb_ShieldGrid::setSector(int sectorIndex, sb_SectorType newValue)
{
	if (sectorIndex < totalSectors)
	{
		sector[sectorIndex] = newValue;
	}
}

sb_SectorType sb_ShieldGrid::getSectorValue(int x, int y)
{
	int sectorIndex;
	
	if (x < xSectors && y < ySectors && x > -1 && y > -1)
	{
		sectorIndex = xSectors*y + x;
		return sector[sectorIndex];
	}
	else
	{
		return kST_NULL;	
	}
}

 //makes necessary changes to grid and returns true(1) if there is a new closure
int sb_ShieldGrid::testForClosure()
{
	int i, x, y;
	int newEnclosure = false;
	
	//the outside array is larger than the sector array so it can have an outside border
	for (y=0; y<50; y++)
	{
		for (x=0; x<66; x++)
		{
			outside[x][y] = false; //blank the outside array
		}
	}
	
	//starting with upper left area traverse the entire playfield
	//set all the elements of outside to true if it can be reached 
	//without passing through shields
	setSurroundingSectorsToOutside(0,0);
	
	//now we need to compare against the shieldGrid and make any updates if something has changed
	//we start inset one so it matches the size of the shieldGrid (sector array)
	i=0;
	for (y=1; y<49; y++)
	{
		for (x=1; x<65; x++)
		{
			//if the it's vacant but the outside array says it's not outside we need to change it
			if (sector[i] == kST_vacant && outside[x][y] == false )
			{
				sector[i] = kST_insideShield;
				newEnclosure = true;
			}
			//if an inactive object is now inside it should be made active
			if (sector[i] == kST_inactiveObject && outside[x][y] == false )
			{
				sector[i] = kST_activeObject;
				newEnclosure = true;
			}

			i++;
		}
	}	
	return newEnclosure; //let the calling function know whether something changed
}

//recursive function that sets adjacent Sectors to outside until it has hit all deadends
void sb_ShieldGrid::setSurroundingSectorsToOutside(int sectorX, int sectorY)
{
	//if this index doesn't even exist we've hit the outside of the area
	if (sectorX >= xSectors+2 || sectorX < 0 || sectorY >= ySectors+2 || sectorY < 0) //+2 because of the border
	{
		return; //end this branch of the recursive searching
	}
	//if we've all ready been to this area 
	if (outside[sectorX][sectorY] == true)
	{
		return; //end this branch of the recursive searching
	}
	//if the offset from the outside array (with its extra border) is inside the sector range
	if (sectorX >= 1 && sectorY >= 1 && sectorX <= xSectors && sectorY <= ySectors)
	{
		//if this index is a shield we have hit a dead end
		if (sector[(sectorY-1)*xSectors+(sectorX-1)] == kST_shield) //-1 to compensate for border
		{
			return; //end this branch of the recursive searching
		}
	}

	//if we get here this particular area must be on the outside
	outside[sectorX][sectorY] = true;
	//now we must check all the surroundingSectors using this function
	setSurroundingSectorsToOutside(sectorX-1, sectorY-1); //upper left
	setSurroundingSectorsToOutside(sectorX, sectorY-1); //up
	setSurroundingSectorsToOutside(sectorX+1,sectorY-1); //upper right
	setSurroundingSectorsToOutside(sectorX-1, sectorY); //left
	//we don't check this same square again because we'd get an endless recurssion
	setSurroundingSectorsToOutside(sectorX+1, sectorY); //right
	setSurroundingSectorsToOutside(sectorX-1, sectorY+1); //lower left
	setSurroundingSectorsToOutside(sectorX, sectorY+1); //down
	setSurroundingSectorsToOutside(sectorX+1, sectorY+1); //lower right
	return;
}


int sb_ShieldGrid::sectorOnDot(int dotX, int dotY)
{
	int sectorIndex, sectorX, sectorY;
	sectorX = dotX / sectorSize;
	sectorY = dotY / sectorSize;

	if (sectorX < xSectors && sectorY < ySectors && sectorX > -1 && sectorY > -1)
	{
		sectorIndex = xSectors*sectorY + sectorX;
		return sectorIndex;
	}
	else
	{
		return -1;
	}
}

//return grid x and y of sector on pixel coordinate
//points are both -1 if it does not fit
sb_point sb_ShieldGrid::sectorPointOnDot(int dotX, int dotY) 
{
	sb_point tempPoint;
	tempPoint.x = dotX / sectorSize;
	tempPoint.y = dotY / sectorSize;
	
	if (tempPoint.x < xSectors && tempPoint.y < ySectors && tempPoint.x > -1 && tempPoint.y > -1)
	{
		return tempPoint;
	}
	else
	{
		tempPoint.x = -1;
		tempPoint.y = -1;
		return tempPoint;
	}
}

sb_point sb_ShieldGrid::cornerClosestTo(int dotX, int dotY)
{
	sb_point temp;
	int sectorPointIsIn;
	int sectorX, sectorY;
	
	sectorPointIsIn = sectorOnDot(dotX,dotY);
	//find the upper x and y of this sector
	sectorY = sectorPointIsIn/xSectors; //remainder is truncated, y value is quotient
	sectorX = sectorPointIsIn%xSectors; //remainder has the x value of the row
	temp.x = sectorX * sectorSize - sectorSize/2; //screen coordinates
	temp.y = sectorY * sectorSize - sectorSize/2;
	
	//now change temp to the corner dotX and dotY are closest to
	if ( dotX >= temp.x + sectorSize/2 ) //if it's more than halfway past move one block over
	{
		temp.x += sectorSize;
	}
	if ( dotY >= temp.y + sectorSize/2 )
	{
		temp.y += sectorSize;
	}
	
	return temp;
}

sb_vector sb_ShieldGrid::cornerDiffFromDot(int dotX, int dotY)
{
	sb_vector temp;
	sb_point corner;
	
	corner = cornerClosestTo(dotX, dotY);
	
	temp.dx = corner.x - dotX;
	temp.dy = corner.y - dotY;
	return temp;
}

float sb_ShieldGrid::getRandomSparkleOffset()
{
	float rso;
	rso = RandomSparkleOffset[rsoIndex];
	rsoIndex++;
	if (rsoIndex >= 499)
	{
		rsoIndex = 0;
	}
	
	return rso;
}

//accessors
int sb_ShieldGrid::getXRes()
{
	return xRes;
}
int sb_ShieldGrid::getYRes()
{
	return yRes;
}
int sb_ShieldGrid::getSectorSize()
{
	return sectorSize;
}
int sb_ShieldGrid::getXSectors()
{
	return xSectors;
}
int sb_ShieldGrid::getYSectors()
{
	return ySectors;
}
int sb_ShieldGrid::getTotalSectors()
{
	return totalSectors;
}
sb_color sb_ShieldGrid::getColor()
{
	sb_color tempColor;
	tempColor.r = r;
	tempColor.g = g;
	tempColor.b = b;
	tempColor.a = a;
	return tempColor;
}