//Copyright (c) 2004 Aaron Sullivan. All rights reserved.
#ifndef SB_SHIELDGRID_H
#define SB_SHIELDGRID_H

#include "sb_global.h"
#include "SDL.h"
#include "RNG.h"

enum sb_SectorType
{
	kST_NULL = -1,
	kST_vacant,
	kST_insideShield,
	kST_inactiveObject,
	kST_activeObject,
	kST_outOfRange,
	kST_shield
};

//***currently only works with a fixed size hard coded in

class sb_ShieldGrid
{
public:
	sb_ShieldGrid();
	~sb_ShieldGrid();
	void reset();
	
	void setColor(float red, float green, float blue, float alpha);
	void displayGrid();
	void displayGrid(float centerX, float centerY, int area);

	void displayShields();
	void setSector(int x, int y, sb_SectorType newValue);
	void setSector(int sectorIndex, sb_SectorType newValue);
	sb_SectorType getSectorValue(int x, int y);
	
	int testForClosure(); //makes necessary changes to grid and returns true(1) if there is a new closure
	
	int sectorOnDot(int dotX, int dotY ); //return index number of sector on pixel coordinate
	sb_point sectorPointOnDot(int dotX, int dotY); //return grid x and y of sector on pixel coordinate
	
	sb_point cornerClosestTo(int dotX, int dotY);
	sb_vector cornerDiffFromDot(int dotX, int dotY);
	
	//accessors
	int getXRes();
	int getYRes();
	int getSectorSize();
	int getXSectors();
	int getYSectors();
	int getTotalSectors();
	sb_color getColor();
	
	//friend classes
	friend class sb_ShieldSection;
	friend class sb_Phase_SetStage;
	
private:
	int xRes;
	int yRes;
	int sectorSize;
	int xSectors;
	int ySectors;
	int totalSectors; //3072 comes from (1024/16)*(768/16)
	//array to hold the value of each sector in the entire ShieldGrid
	sb_SectorType sector[3072]; //64 x 48
	int outside[66][50]; //used to keep track of Sectors that are outside of closure
	                     //it has an extra border around it for enclosure checking
	float r, g, b, a;
	
	//recursive function to determine what is outside of shields
	void setSurroundingSectorsToOutside(int sectorX, int sectorY);
	
	//random sparkle
	RNG rng;
	float RandomSparkleOffset[500];
	int rsoIndex;
	float getRandomSparkleOffset();
};

typedef sb_ShieldGrid* sb_ShieldGridPtr;

#endif