//Copyright (c) 2004 Aaron Sullivan. All rights reserved.
#include "sb_ShieldSection.h"
#include <iostream.h>

void sb_ShieldSection::init(sb_ShieldGridPtr relatedShieldGrid)
{
	shieldGrid = relatedShieldGrid;
	centerX = 0;
	centerY = 0;
	
	totalShapes = 11;
	
	sectorSize = shieldGrid->sectorSize;
	xSectors = 5;
	ySectors = 5;
	totalSectors = xSectors * ySectors;
	int i;
	for (i=0; i<totalSectors; i++)
	{
		sector[i] = kST_vacant;
		offendingSector[i] = kST_vacant;
	}
	osGlow = 0.0f; //offendingSectors only glow when needed
	
	setColor(1.0f, 1.0f, 0.0f, 0.6f);
	rotation = 0.0f;
	rotating = false;
	rotateCommandQueue = 0;
	
	sector[12] = kST_shield; //set the center sector to on as default (a single square)	
}

void sb_ShieldSection::move(float x, float y)
{
	//could put checks here to make sure piece doesn't go off the edge...
	centerX = x;
	centerY = y;
}

void sb_ShieldSection::reshape(int shapeNumber)
{
	if (shapeNumber >= 0 && shapeNumber < totalShapes)
	{
		//clear out the array
		int i;
		for (i=0; i<totalSectors; i++)
		{
			sector[i] = kST_vacant;
			offendingSector[i] = kST_vacant;
		}
		
		//set new shape
		switch(shapeNumber)
		{
			case 0:
				//basic one square shape
				sector[12] = kST_shield;
				break;
			case 1:
				//basic two square shape
				sector[12] = kST_shield;
				sector[13] = kST_shield;
				break;
			case 2:
				//short 'L' shape
				sector[12] = kST_shield;
				sector[13] = kST_shield;
				sector[7] = kST_shield;
				break;
			case 3:
				//2x2 square shape
				sector[12] = kST_shield;
				sector[13] = kST_shield;
				sector[7] = kST_shield;
				sector[8] = kST_shield;
				break;
			case 4:
				//long 'L' shape
				sector[12] = kST_shield;
				sector[7] = kST_shield;
				sector[17] = kST_shield;
				sector[18] = kST_shield;
			case 5:
				//inverted long 'L' shape
				sector[12] = kST_shield;
				sector[7] = kST_shield;
				sector[8] = kST_shield;
				sector[17] = kST_shield;
				break;
			case 6:
				//step shape
				sector[12] = kST_shield;
				sector[7] = kST_shield;
				sector[6] = kST_shield;
				sector[13] = kST_shield;
				break;
			case 7:
				//inverted step shape
				sector[12] = kST_shield;
				sector[7] = kST_shield;
				sector[8] = kST_shield;
				sector[11] = kST_shield;
				break;
			case 8:
				//tall step shape
				sector[12] = kST_shield;
				sector[7] = kST_shield;
				sector[8] = kST_shield;
				sector[17] = kST_shield;
				sector[16] = kST_shield;
				break;
			case 9:
				//inverted tall step shape
				sector[12] = kST_shield;
				sector[7] = kST_shield;
				sector[6] = kST_shield;
				sector[17] = kST_shield;
				sector[18] = kST_shield;
				break;
			case 10:
				// 'C' shape
				sector[12] = kST_shield;
				sector[7] = kST_shield;
				sector[8] = kST_shield;
				sector[17] = kST_shield;
				sector[18] = kST_shield;
				break;
		}
	}
}

void sb_ShieldSection::animate(Uint32 ticks)
{
	//take care of rotation of section
	if (rotating)
	{
		rotation += (0.5f * ticks);
		if (rotation >= 90)
		{
			rotating = false;
			rotation = 0.0f;
			rotateFinish();
			if (rotateCommandQueue > 0)
			{
				rotateCommandQueue--;
				rotate();
			}
		}
	}
	
	//take care of glow of offendingSectors (parts that didn't fit into shieldGrid)
	osGlow = osGlow - 0.003f*ticks;
	if (osGlow < 0.0f)
	{
		osGlow = 0.0f;
	}
}

void sb_ShieldSection::rotate()
{
	if (rotating == true)
	{
		rotateCommandQueue++;
	}
	rotating = true;
}

void sb_ShieldSection::rotateFinish()
{	
	sb_SectorType tempsector[5][5]; //this is just bad programming :) If I wanted to change the size of the shieldSection it's going to cause lots of problems
	sb_SectorType tempOffend[5][5];
	int ix, iy;
	int i;
	i=0;
	for (ix = 4; ix >= 0; ix--)
	{
		for (iy = 0; iy < 5; iy++)
		{
			tempsector[ix][iy] = sector[i];
			tempOffend[ix][iy] = offendingSector[i];
			i++;
			if (i == totalSectors) {break;}
		}
	}
	
	i=0;
	for (iy = 0; iy < 5; iy++)
	{
		for (ix = 0; ix < 5; ix++)
		{
			sector[i] = tempsector[ix][iy];
			offendingSector[i] = tempOffend[ix][iy];
			i++;
		}
	}
}

void sb_ShieldSection::rotateCC()
{
	//***currently does nothing!
}

void sb_ShieldSection::display()
{
	int i;
	float x, y;
	float leftmostX, rightmostX, topmostY;
	//move to a relative position and draw out from there.
	//this way we can rotate simply and don't need to calculate exact screen coordinates
	
	glAAFlush();
	glLoadIdentity();  //reset glcoordinates coordinates
	glTranslatef(centerX, centerY,0.0f);
	glRotatef(rotation,0.0f,0.0f,1.0f);
		
	leftmostX = -((float)(xSectors/2)*sectorSize); //first square is minus one half the total length (truncated to 2) * the pixel size of each sector
	rightmostX = ((float)(xSectors/2)*sectorSize);
	topmostY = -((float)(ySectors/2)*sectorSize);
	
	x = leftmostX;
	y = topmostY;

	//draw offendingSectors as center points
    if (osGlow > 0)
	{
		glAALineWidth(3.0f);
		glAAPointSize(4.0f);
		glAAColor4f(osGlow,0.1f,0.1f,CLAMP(a+0.2f,0.0f,1.0f));

		for (i=0; i < totalSectors; i++)
		{
			if (offendingSector[i] == kST_shield)
			{
				glAABegin(GL_POINTS);
				glAAVertex2f(x,y);
				glAAEnd();
				glAABegin(GL_LINE_STRIP);
				glAAVertex2f( x+ shieldGrid->getRandomSparkleOffset(), y + shieldGrid->getRandomSparkleOffset());
				glAAVertex2f( x+ shieldGrid->getRandomSparkleOffset(), y + shieldGrid->getRandomSparkleOffset());
				glAAEnd();
			}
			x += sectorSize;
			if ((i+1) % xSectors == 0) //if we are at the rightmost block (the next block is evenly divided by the number of blocks in one row)
			{
				x = leftmostX;
				y += sectorSize;
			}
		}
	}


	//draw top shield lines for squares that are "on" (not zero)
	x=leftmostX - sectorSize/2;
	y=topmostY - sectorSize/2;
	glAALineWidth(2);
	glAAColor4f(r,g,b,a);
	
	for (i=0; i < xSectors; i++)
	{
		if (sector[i] == kST_shield)
		{
			glAABegin(GL_LINE_STRIP);
			glAAVertex2f( x +.05 , y);
			glAAVertex2f( x + sectorSize - 0.5,y);
			glAAEnd();
		}
		x += sectorSize;
	}
	
	x=leftmostX - sectorSize/2;
	y=topmostY - sectorSize/2;
	for (i=0; i < totalSectors; i++) //loop through all lines except last one
	{
		if (i % xSectors == 0) //if this is the left most square of this line
		{
			if (sector[i] == kST_shield)//if this square is on
			{
				//draw a vertical line on the left
				glAABegin(GL_LINE_STRIP);
				glAAVertex2f( x, y + 0.5);
				glAAVertex2f( x, y + sectorSize - 0.5);
				glAAEnd();
			}
		}
		
		if ((i+1) % xSectors == 0) //if this is the last square of this line
		{
			if (sector[i] == kST_shield)//if this square is on
			{
				//draw a vertical line on the right
				glAABegin(GL_LINE_STRIP);
				glAAVertex2f( x + sectorSize, y + 0.5);
				glAAVertex2f( x + sectorSize, y + sectorSize - 0.5);
				glAAEnd();
			}
		}
		else //do normal check to the right
		{
			//if the square to the right is on and this one is off... or visa versa
			if ((sector[i] != kST_shield && sector[i+1] == kST_shield) || 
				(sector[i] == kST_shield && sector[i+1] != kST_shield))
			{
				//draw a vertical line on the right
				glAABegin(GL_LINE_STRIP);
				glAAVertex2f( x + sectorSize, y + 0.5);
				glAAVertex2f( x + sectorSize, y + sectorSize - 0.5);
				glAAEnd();
			}
		}
		
		if (i+xSectors >= totalSectors) //if we are on the bottom line
		{
			if (sector[i] == kST_shield) //if this square is "on"
			{
				//draw a horizontal line below
				glAABegin(GL_LINE_STRIP);
				glAAVertex2f( x +.05 , y + sectorSize - 0.5);
				glAAVertex2f( x + sectorSize - 0.5, y + sectorSize - 0.5);
				glAAEnd();
			}
		}
		else //do a normal check below
		{
			//if the square below is on and this one is off... or visa versa
			if ((sector[i] == kST_shield && sector[i+xSectors] != kST_shield ) || 
				(sector[i] != kST_shield && sector[i+xSectors] == kST_shield))
			{
				//draw a horizontal line below
				glAABegin(GL_LINE_STRIP);
				glAAVertex2f( x +.05 , y + sectorSize - 0.5);
				glAAVertex2f( x + sectorSize - 0.5, y + sectorSize - 0.5);
				glAAEnd();
			}
		}
		x += sectorSize;
		if(x > rightmostX)
		{
			x=leftmostX - sectorSize/2;;
			y += sectorSize;
		}
	}
	
}

void sb_ShieldSection::displayCursor()
{
	int i;
	float x, y;
	float leftmostX, rightmostX, topmostY;
	//move to a relative position and draw out from there.
	//this way we can rotate simply and don't need to calculate exact screen coordinates
	
	glAAFlush();
	glLoadIdentity();  //reset glcoordinates coordinates
	glTranslatef(centerX, centerY,0.0f);
	glRotatef(rotation,0.0f,0.0f,1.0f);
	
	leftmostX = -((float)(xSectors/2)*sectorSize); //first square is minus one half the total length (truncated to 2) * the pixel size of each sector
	rightmostX = ((float)(xSectors/2)*sectorSize);
	topmostY = -((float)(ySectors/2)*sectorSize);
	
	x = leftmostX;
	y = topmostY;
	
	//draw top shield lines for squares that are "on" (not zero)
	x=leftmostX - sectorSize/2;
	y=topmostY - sectorSize/2;
	glAALineWidth(2);
	glAAColor4f(r,g,b,a);
	
	for (i=0; i < xSectors; i++)
	{
		if (sector[i] == kST_shield)
		{
			glAABegin(GL_LINE_STRIP);
			glAAVertex2f( x +.05 , y);
			glAAVertex2f( x + sectorSize - 0.5,y);
			glAAEnd();
		}
		x += sectorSize;
	}
	
	x=leftmostX - sectorSize/2;
	y=topmostY - sectorSize/2;
	for (i=0; i < totalSectors; i++) //loop through all lines except last one
	{
		if (i % xSectors == 0) //if this is the left most square of this line
		{
			if (sector[i] == kST_shield)//if this square is on
			{
				//draw a vertical line on the left
				glAABegin(GL_LINE_STRIP);
				glAAVertex2f( x, y + 0.5);
				glAAVertex2f( x, y + sectorSize - 0.5);
				glAAEnd();
			}
		}
		
		if ((i+1) % xSectors == 0) //if this is the last square of this line
		{
			if (sector[i] == kST_shield)//if this square is on
			{
				//draw a vertical line on the right
				glAABegin(GL_LINE_STRIP);
				glAAVertex2f( x + sectorSize, y + 0.5);
				glAAVertex2f( x + sectorSize, y + sectorSize - 0.5);
				glAAEnd();
			}
		}
		else //do normal check to the right
		{
			//if the square to the right is on and this one is off... or visa versa
			if ((sector[i] != kST_shield && sector[i+1] == kST_shield) || 
				(sector[i] == kST_shield && sector[i+1] != kST_shield))
			{
				//draw a vertical line on the right
				glAABegin(GL_LINE_STRIP);
				glAAVertex2f( x + sectorSize, y + 0.5);
				glAAVertex2f( x + sectorSize, y + sectorSize - 0.5);
				glAAEnd();
			}
		}
		
		if (i+xSectors >= totalSectors) //if we are on the bottom line
		{
			if (sector[i] == kST_shield) //if this square is "on"
			{
				//draw a horizontal line below
				glAABegin(GL_LINE_STRIP);
				glAAVertex2f( x +.05 , y + sectorSize - 0.5);
				glAAVertex2f( x + sectorSize - 0.5, y + sectorSize - 0.5);
				glAAEnd();
			}
		}
		else //do a normal check below
		{
			//if the square below is on and this one is off... or visa versa
			if ((sector[i] == kST_shield && sector[i+xSectors] != kST_shield ) || 
				(sector[i] != kST_shield && sector[i+xSectors] == kST_shield))
			{
				//draw a horizontal line below
				glAABegin(GL_LINE_STRIP);
				glAAVertex2f( x +.05 , y + sectorSize - 0.5);
				glAAVertex2f( x + sectorSize - 0.5, y + sectorSize - 0.5);
				glAAEnd();
			}
		}
		x += sectorSize;
		if(x > rightmostX)
		{
			x=leftmostX - sectorSize/2;;
			y += sectorSize;
		}
	}
}

void sb_ShieldSection::displayInGrid()
{

	float originalAlpha, oR, oG, oB;
	
	displayAlignedWithGrid();
	
	originalAlpha = a;
	oR = r;
	oG = g;
	oB = b;
	
	a = a*0.75; //use a percentage of the alpha for the piece that represents the mouse location
	r = shieldGrid->r;
	g = shieldGrid->g;
	b = shieldGrid->b;
	displayCursor(); //display in it's actual location (that is probably offset from the shieldGrid
	a = originalAlpha;
	r = oR;
	g = oG;
	b = oB;
}

void sb_ShieldSection::displayAlignedWithGrid()
{
	float originalX, originalY;
	sb_vector changeToFit;
	
	originalX = centerX; //keep a record of where the section is so we can restore it
	originalY = centerY;
	
	changeToFit = shieldGrid->cornerDiffFromDot((int)originalX,(int)originalY); //find the distance to the nearest corner
	centerX += changeToFit.dx; //offset the center temporarily
	centerY += changeToFit.dy;
	display();
	centerX = originalX; //restore the original center
	centerY = originalY;
}

int sb_ShieldSection::fitIntoGrid()
{
	if (rotation != 0.0f) return false;
	
	int SectorsToFill[totalSectors]; //this will hold the indexes of the shield that we can fill
	int i, ctfi, shieldIndex; //ctfi is index for SectorsToFill array
	float dotX, dotY;
	int fits; //false if a shield sector was underneath the section we were trying to add.
	
	float leftmostX = centerX - ((float)(xSectors/2)*sectorSize); //first square is minus one half the total length (truncated to 2) * the pixel size of each sector
	float rightmostX = centerX + ((float)(xSectors/2)*sectorSize);
	float topmostY = centerY - ((float)(ySectors/2)*sectorSize);
	
	dotX = leftmostX;
	dotY = topmostY;
	
	ctfi = 0;
	fits = true;
	
	//clear out the offendingSector array because this is a new attempt
	for (i=0; i<totalSectors; i++)
	{
		offendingSector[i] = kST_vacant;
	}
	
	for (i=0; i<totalSectors; i++)
	{
		if (sector[i] == kST_shield)
		{
			if (dotX >= 0 && dotX <= shieldGrid->xRes && dotY >= 0 && dotY <= shieldGrid->yRes) //if the sector is on the screen
			{
				shieldIndex = shieldGrid->sectorOnDot((int)dotX, (int)dotY); //get the shieldsector that is under this sectionsector
				if (shieldGrid->sector[shieldIndex] == kST_vacant ||
					shieldGrid->sector[shieldIndex] == kST_insideShield ) //if there is no obstruction
				{
					SectorsToFill[ctfi] = shieldIndex;
					ctfi++;
				}
				else
				{
					offendingSector[i] = kST_shield;
					fits = false; //this section can't go down... we won't leave the loop so we can continue to fill the offending sector array
				}
			}
			else
			{
				fits = false;
			}
		}
		dotX += sectorSize;
		if (dotX > rightmostX)
		{
			dotX = leftmostX;
			dotY += sectorSize;
		}
	}
	SectorsToFill[ctfi] = -1;
	
	if(fits)
	{
		ctfi = 0;
		while (SectorsToFill[ctfi] != -1)
		{
			shieldGrid->sector[SectorsToFill[ctfi]] = kST_shield;
			ctfi++;
		}
	}
	else
	{
		osGlow = 1.0f;
	}
	return fits;
}

void sb_ShieldSection::setColor(float red, float green, float blue, float alpha)
{
	r = CLAMP(red, 0.0f, 1.0f);
	g = CLAMP(green, 0.0f, 1.0f);
	b = CLAMP(blue, 0.0f, 1.0f);
	a = CLAMP(alpha, 0.0f, 1.0f);
}