//Copyright (c) 2004 Aaron Sullivan. All rights reserved.

#ifndef SB_GLOBAL_H
#define SB_GLOBAL_H

#define SB_DEFAULT_SOUND_RATE 22050
#define SB_DEFAULT_SOUND_CHANNELS 2
#define SB_DEFAULT_SOUND_BUFFERS 128

#include "SDL.h"
#include <math.h>
#include <iostream.h>

extern "C" {
#include "AAPrimitives.h"
#include "AAUtilities.h"
#include "VectroFont.h"
}

#include "sb_Circle.h"

struct sb_point
{
	float x, y;
};

struct sb_vector
{
	float dx, dy;
};

struct sb_color
{
	float r, g, b, a;
};

#define k_piDivBy180 0.01745329f
#define k_180DivByPi 57.29582

//find cosine of an angle in degrees
static inline float sb_cosD( float angleInDegrees )
{
	float angleInRadians;
	if (angleInDegrees == 90.0f || angleInDegrees == 270.0f)
	{
		return 0.0f;
	}
	else if (angleInDegrees == 0.0f)
	{
		return 1.0f;
	}
	else if (angleInDegrees == 180.0f)
	{
		return -1.0f;
	}
	else
	{
		angleInRadians = angleInDegrees * k_piDivBy180;
		return cos(angleInRadians);
	}
}

//find sine of an angle in degrees
static inline float sb_sinD( float angleInDegrees )
{
	float angleInRadians;
	if (angleInDegrees == 0.0f || angleInDegrees == 180.0f)
		{
		return 0.0f;
		}
	else if (angleInDegrees == 90.0f)
		{
		return 1.0f;
		}
	else if (angleInDegrees == 270.0f)
		{
		return -1.0f;
		}
	else
		{
		angleInRadians = angleInDegrees * k_piDivBy180;
		return sin(angleInRadians);
		}
}

//find angle in degrees that is arctangent of an number 
static inline float sb_atanD( float x )
{
	float angleInRadians;

	angleInRadians = atan( x );
	return angleInRadians * k_180DivByPi; //convert to degrees
}



//*this next function doesn't seem to work correctly.  No time to fix it. Sigh.
//automatically grow and diminish a number given only the number, the amt to change (in one step) and the min and max
static inline void throb(float &varToThrob, float amt, float min, float max)
{
	amt = CLAMP(amt, 0.002f, max-min);
	
	//we use varToThrob's divisibility by 0.002 to determine whether we increase or decrease it
	if ((int)(varToThrob*1000) % 2 == 0) 	{
		varToThrob += amt;
	}
	else
	{
		varToThrob -= amt;
	}
	
	//if we hit a limit, we need to change varToThrob's divisibility by 0.002
	if (varToThrob < min)
	{
		if ((int)(min*1000) % 2 != 0)
		{
			varToThrob = min + .001; //if it's not divisible by .002 then this function will increase it
		}
		else
		{
			varToThrob = min;
		}
	}
	
	if (varToThrob > max)
	{
		if ((int)(max*1000) % 2 == 0)
		{
			varToThrob = max - 0.001;
		}
		else 
		{
			varToThrob = max;
		}
	}
}

//easier to read replacements
typedef SDL_Surface* SDL_SurfacePtr; 
typedef SDL_PixelFormat* SDL_PixelFormatPtr;

/*SDL.h gives us these AND checks to be sure they are correct for the platform we are using
typedef unsigned char	Uint8;
typedef signed char	    Sint8;
typedef unsigned short	Uint16;
typedef signed short	Sint16;
typedef unsigned int	Uint32;
typedef signed int	    Sint32;

struct {
    SDL_FALSE = 0,
    SDL_TRUE = 1
}SDL_bool;

#define SDL_TABLESIZE(table)    (sizeof(table)/sizeof(table[0]))

From SDL_video.h we get:

#define SDL_ALPHA_OPAQUE 255
#define SDL_ALPHA_TRANSPARENT 0

typedef struct {
    Sint16 x, y;
    Uint16 w, h;
} SDL_Rect;

typedef struct {
    Uint8 r;
    Uint8 g;
    Uint8 b;
    Uint8 unused;
} SDL_Color;

*/
#endif