/*
 *  AAPrimitives.h
 *  glAArg version 0.1.3
 *
 *  Created by arekkusu on Thu Nov 20 2003.
 *  Copyright (c) 2004 arekkusu. All rights reserved.
 *  http://homepage.mac.com/arekkusu/bugs/invariance/
 *
 */

#ifndef __AAPRIMITIVES__
#define __AAPRIMITIVES__

#include <CoreServices/CoreServices.h>
#include <OpenGL/OpenGL.h>
#include <OpenGL/gl.h>
#include <OpenGL/glu.h>
#include <OpenGL/glext.h>
#include "AAUtilities.h"


#ifdef __cplusplus
extern "C" {
#endif


// the point half-width in px. must be a power of two <= 256. 64 is a good size for a bitmap font to fit in the unused space.
// eventually this constant will probably be passed as an argument to glAAGenerateAATex() but it is hardcoded here for now.
#define phf 32

// VAR constants; could be determined empirically at runtime depending on the GPU, but hardcoded here for now.
// VAR_size*VAR_bufs must be <65536 to let the index be an unsigned short
#define VAR_size 32768
#define VAR_bufs 2


// basic 2D types
typedef struct GLCoord2 {
    GLfloat	x;
    GLfloat	y;
} GLCoord2;

typedef struct Vertex {
    GLuint	rgba;				// assumes big-endian architecture
    GLfloat	x;
    GLfloat	y;
    GLfloat	tx;
    GLfloat	ty;
} Vertex;   


// expose these globals for client access
extern GLuint			glAA_texture[8];
extern unsigned char	*glAA_AAtex[8];


// glAA API
void glAAInit();
void glAAExit();
void glAAGenerateAATex(float falloff, GLuint id, bool alias);
void glAABegin(GLenum mode);
void glAAEnd();
void glAAFlush();
void glAAEnable(GLenum cap);
void glAADisable(GLenum cap);
void glAAPointSize(GLfloat size);
void glAAPointLight(GLCoord2 light);
void glAALineWidth(GLfloat width);
void glAALineStipple (GLint factor, GLushort pattern);
void glAALineStipplePhase (GLfloat factor, GLushort pattern, GLfloat phase); /* this is buggy */
void glAAColor3f(float R, float G, float B);
void glAAColor4f(float R, float G, float B, float A);
void glAAColor4ubv(const GLubyte *c);
void glAAColor1ui(GLuint c);
void glAAVertex2f(GLfloat x, GLfloat y);


#ifdef __cplusplus
}
#endif

#endif //__AAPRIMITIVES__
