/*
 *  AAUtilities.h
 *  glAArg version 0.1.3
 *
 *  Created by arekkusu on Fri Mar 26 2004.
 *  Copyright (c) 2004 arekkusu. All rights reserved.
 *
 */
#ifndef __AAUTILITIES__
#define __AAUTILITIES__

#include <ppc_intrinsics.h>


// useful macros
#ifndef MIN
    #define MIN(A,B)	((A) < (B) ? (A) : (B))
#endif
#ifndef MAX
    #define MAX(A,B)	((A) > (B) ? (A) : (B))
#endif
#ifndef CLAMP
	#define CLAMP(x, low, high)  (((x) > (high)) ? (high) : (((x) < (low)) ? (low) : (x)))
#endif


// ---------------------------------------------------------------------
// fast reciprocal square root estimate with Newton-Raphson refinement
// ---------------------------------------------------------------------
static inline float frsqrtes_nr(float x) {
	float e = __frsqrtes(x);
	e *= (1.5f - (0.5f * x * e * e));
	return e;
}


// ---------------------------------------------------------------------
// linear interpolation between two RGBA colors. t [0..1]
// ---------------------------------------------------------------------
static inline unsigned int lerpRGBA(const unsigned int d, const unsigned int s, const float t) {
	unsigned int ti = t*256;
	unsigned int dstga = d      & 0xFF00FF;
	unsigned int dstrb = d >> 8 & 0xFF00FF;
	unsigned int srcga = s      & 0xFF00FF;
	unsigned int srcrb = s >> 8 & 0xFF00FF;
	unsigned int dga = srcga - dstga;
	unsigned int drb = srcrb - dstrb;
	dga = (dga * ti) >> 8;  
	drb = (drb * ti) >> 8;  
	const unsigned int ga  = (dga + dstga)      & 0x00FF00FF;
	const unsigned int rb  = (drb + dstrb) << 8 & 0xFF00FF00;
	return ga | rb;
}


// ---------------------------------------------------------------------
// component scale and saturate RGB color. s [0..512]
// ---------------------------------------------------------------------
static inline unsigned int scalesatRGB(const unsigned int c, const unsigned short s) {
	unsigned int r =  ((c >> 24)               * s) >> 8;
	unsigned int g = (((c >> 16) & 0x000000FF) * s) >> 8;
	unsigned int b = (((c >>  8) & 0x000000FF) * s) >> 8;
	unsigned int a =   c         & 0x000000FF;
	r = MIN(r, 255);
	g = MIN(g, 255);
	b = MIN(b, 255);
	unsigned int end = (r<<24) | (g<<16) | (b<<8) | a;
	return end;
}

#endif //__AAUTILITIES__