/*
 *  VectroFont.c
 *  VectroGames
 *
 *  Created by arekkusu on Mon Mar 08 2004.
 *  Copyright (c) 2004 arekkusu. All rights reserved.
 *
 */

#include "VectroFont.h"
#import "AAPrimitives.h"

static float vf_xscale = 1.0;
static float vf_yscale = 1.0;
static float vf_xtrack = 0.0;
static float vf_ytrack = 15.0;
static float vf_xloc   = 0.0;
static float vf_yloc   = 0.0;
static float vf_left   = 0.0;
static float vf_right  = 0.0;
static float vf_top    = 0.0;
static float vf_bottom = 0.0;


void vf_setpenscale(float x, float y) {
	vf_xscale = x;
	vf_yscale = y;
}


void vf_setpentrack(float x, float y) {
	vf_xtrack = x;
	vf_ytrack = y;
}


void vf_setpenloc(float x, float y) {
	vf_xloc = x;
	vf_yloc = y;
}


void vf_setpage(float x, float y, float w, float h) {
	vf_left = x;
	vf_right = x+w;
	vf_top = y;
	vf_bottom = y+h;
}


// extremely simple hardcoded 7-bit ASCII vector font format:
// each char is defined on an grid using integral positions (typically a 16x18 grid per char)
// positive values are the grid x,y location. the following values have special meaning:
//  0: end of char
// -1: start point
// -2: start line strip
// -x: translate right x units (typically the width of the char + 2)

const char logo[] = {
	    1, 1, 5, 11, -2, 8, 17, 8, 17, -2, 11, 11, 15, 1, -18,											// V
	-2, 15, 1, 3, 1, 1, 3, 1, 15, 3, 17, 15, 17, -2, 8, 9, 8, 9, -18,									// E
	-2, 15, 1, 3, 1, 1, 3, -2, 1, 9, 1, 9, -2, 1, 15, 3, 17, 15, 17, -18,								// C
	-2, 1, 1, 6, 1, 8, 3, 8, 17, -2, 15, 1, 15, 1, -18,													// T
	-2, 1, 17, 1, 3, 3, 1, 13, 1, 15, 3, 15, 7, 13, 9, 8, 9, -2, 15, 17, 15, 17, -18,					// R
	-2, 13, 1, 3, 1, 1, 3, 1, 15, 3, 17, 13, 17, 15, 15, 15, 3, 13, 1, -2, 8, 9, 8, 9, -18,				// O
	-2, 15, 1, 3, 1, 1, 3, -2, 1, 9, 1, 9, -2, 1, 15, 3, 17, 13, 17, 15, 15, 15, 11, 13, 9, 8, 9, -18,  // G
	-2, 1, 17, 8, 1, 15, 17, -2, 8, 17, 8, 17, -2, -18,													// A
	-2, 15, 17, 15, 3, 13, 1, 3, 1, 1, 3, 1, 17, -2, 8, 9, 8, 9, -18,									// M
	-2, 15, 1, 3, 1, 1, 3, 1, 15, 3, 17, 15, 17, -2, 8, 9, 8, 9, -18,									// E
	-2, 15, 1, 3, 1, 1, 3, -2, 8, 9, 8, 9, -2, 1, 17, 13, 17, 15, 15,	0								// S
};

int vf_charwidth(char c) {
	const char *v = vf_ASCII[(int)c&0x7F];
	int w = 0, i;
	char x;
	if (v) {
		for (i = 0; (x = v[i]); i++) {
			if (x < -3) w-=x;
		}
	}
	return w;
}


void vecChar(const char c) {
	const char *v = vf_ASCII[(int)c&0x7F];
	if (v) {
		int i;
		char x;
		glAABegin(GL_LINE_STRIP);						// dead-simple parse through the logo table
		for (i = 0; (x = v[i]); i++) {
				 if (x == -1) { glAAEnd(); glAABegin(GL_POINTS);	 }
			else if (x == -2) { glAAEnd(); glAABegin(GL_LINE_STRIP); }
			else if (x == -3) { vf_yloc += vf_ytrack*vf_yscale; vf_xloc = vf_left;}
			else if (x < 0)   { vf_xloc += -x*vf_xscale + vf_xtrack;			 }
			else			  { glAAVertex2f(vf_xloc + x*vf_xscale, vf_yloc+v[++i]*vf_yscale); }
		}
		glAAEnd();
	}
}

//Altered by Aaron Sullivan 4/7/2004 to add argument list to string (like printf)
void vecString(const char *s, ...) {
	
	//start dealing with "..." (list of arguments like used in printf)
    va_list argumentList;
    char buffer[1024]; //limits size to 1024 characters
    memset(buffer,0,sizeof(buffer));
	
	va_start(argumentList,s);
    vsprintf(buffer,s,argumentList);
    va_end(argumentList);
    //stop dealing with ... (we now have a formatted string in buffer)
	
	if (buffer) {
		int i;
		char x;
		for (i = 0; (x = buffer[i]); i++) {
			vecChar(x);
		}
	}
}


// big pile of hard coded vector data:

const char vf_nl[] = { -3, 0 };

const char vf_sp[] = { -5, 0 };
const char vf_ex[] = { 2, 1, 2, 7, -2, 2, 9, 2, 9, -4, 0 };
const char vf_qd[] = { 1, 1, 1, 3, -2, 3, 1, 3, 3, -4, 0 };
const char vf_ha[] = { 3, 1, 3, 9, -2, 7, 1, 7, 9, -2, 1, 3, 9, 3, -2, 1, 7, 9, 7, -10, 0 };
const char vf_do[] = { 9, 2, 7, 1, 3, 1, 1, 3, 3, 5, 7, 5, 9, 7, 7, 9, 3, 9, 1, 8, -2, 5, -2, 5, 11, 5, 11, -10, 0 };
const char vf_pr[] = { 9, 1, 1, 9, -2, 3, 1, 1, 3, 3, 5, 5, 3, 3, 1, -2, 9, 7, 7, 9, 5, 7, 7, 5, 9, 7, -10, 0 };
const char vf_am[] = { 9, 9, 3, 3, 5, 1, 7, 3, 1, 7, 3, 9, 7, 9, 9, 7, -10, 0 };
const char vf_qs[] = { 2, 1, 2, 3, -4, 0 };
const char vf_lp[] = { 3, 0, 1, 3, 1, 7, 3, 10, -4, 0 };
const char vf_rp[] = { 1, 0, 3, 3, 3, 7, 1, 10, -4, 0 };
const char vf_st[] = { 1, 3, 9, 7, -2, 9, 3, 1, 7, -2, 5, 1, 5, 9, -10, 0 };
const char vf_pl[] = { 1, 5, 9, 5, -2, 5, 1, 5, 9, -10, 0 };
const char vf_cm[] = { 2, 9, 1, 11, -4, 0 };
const char vf_mi[] = { 1, 5, 9, 5, -10, 0 };
const char vf_pe[] = { 2, 9, 2, 9, -4, 0 };
const char vf_fs[] = { 1, 9, 5, 1, -6, 0 };
const char vf_0[]  = { 9, 3, 7, 1, 3, 1, 1, 3, 1, 7, 3, 9, 7, 9, 9, 7, 9, 3, -2, 2, 8, 8, 2, -10, 0 };
const char vf_1[]  = { 1, 9, 9, 9, -2, 5, 9, 5, 1, 3, 3, -10, 0 };
const char vf_2[]  = { 1, 2, 3, 1, 7, 1, 9, 3, 1, 9, 9, 9, -10, 0 };
const char vf_3[]  = { 1, 2, 3, 1, 7, 1, 9, 3, 7, 5, 9, 7, 7, 9, 3, 9, 1, 8, -2, 5, 5, 7, 5, -10, 0 };
const char vf_4[]  = { 7, 9, 7, 1, 1, 5, 9, 5, -10, 0 };
const char vf_5[]  = { 9, 1, 1, 1, 1, 5, 7, 5, 9, 7, 7, 9, 3, 9, 1, 8, -10, 0 };
const char vf_6[]  = { 8, 1, 3, 1, 1, 3, 1, 7, 3, 9, 7, 9, 9, 7, 7, 5, 1, 5, -10, 0 };
const char vf_7[]  = { 1, 1, 9, 1, 5, 9, -10, 0 };
const char vf_8[]  = { 1, 3, 3, 1, 7, 1, 9, 3, 7, 5, 9, 7, 7, 9, 3, 9, 1, 7, 3, 5, 1, 3, -2, 3, 5, 7, 5, -10, 0 };
const char vf_9[]  = { 2, 9, 7, 9, 9, 7, 9, 3, 7, 1, 3, 1, 1, 3, 3, 5, 9, 5, -10, 0 };
const char vf_co[] = { 2, 4, 2, 4, -2, 2, 9, 2, 9, -4, 0 };
const char vf_sc[] = { 2, 9, 1, 11, -2, 2, 4, 2, 4, -4, 0 };
const char vf_lt[] = { 9, 1, 1, 5, 9, 9, -10, 0 };
const char vf_eq[] = { 1, 3, 9, 3, -2, 1, 7, 9, 7, -10, 0 };
const char vf_gt[] = { 1, 1, 9, 5, 1, 9, -10, 0 };
const char vf_qu[] = { 1, 3, 3, 1, 7, 1, 9, 3, 5, 5, 5, 7, -2, 5, 9, 5, 9, -10, 0 };
const char vf_at[] = { 7, 7, 7, 3, 5, 3, 3, 5, 5, 7, 9, 7, 9, 3, 7, 1, 3, 1, 1, 3, 1, 7, 3, 9, 7, 9, -10, 0 };

const char vf_A[]  = { 1, 9, 1, 3, 3, 1, 7, 1, 9, 3, 9, 9, -2, 1, 5, 9, 5, -10, 0 };
const char vf_B[]  = { 1, 9, 1, 1, 7, 1, 9, 3, 7, 5, 1, 5, -2, 7, 5, 9, 7, 7, 9, 1, 9, -10, 0 };
const char vf_C[]  = { 9, 2, 7, 1, 3, 1, 1, 3, 1, 7, 3, 9, 7, 9, 9, 8, -10, 0 };
const char vf_D[]  = { 1, 1, 1, 9, 7, 9, 9, 7, 9, 3, 7, 1, 1, 1, -10, 0 };
const char vf_E[]  = { 9, 1, 1, 1, 1, 9, 9, 9, -2, 1, 5, 7, 5, -10, 0 };
const char vf_F[]  = { 9, 1, 1, 1, 1, 9, -2, 1, 5, 7, 5, -10, 0 };
const char vf_G[]  = { 9, 2, 7, 1, 3, 1, 1, 3, 1, 7, 3, 9, 7, 9, 9, 7, 9, 5, 5, 5, -10, 0 };
const char vf_H[]  = { 1, 1, 1, 9, -2, 1, 5, 9, 5, -2, 9, 1, 9, 9, -10, 0 };
const char vf_I[]  = { 1, 1, 9, 1, -2, 5, 1, 5, 9, -2, 1, 9, 9, 9, -10, 0 };
const char vf_J[]  = { 5, 1, 9, 1, 9, 7, 7, 9, 3, 9, 1, 8, -10, 0 };
const char vf_K[]  = { 1, 1, 1, 9, -2, 9, 1, 1, 5, 9, 9, -10, 0 };
const char vf_L[]  = { 1, 1, 1, 9, 9, 9, -10, 0 };
const char vf_M[]  = { 1, 9, 1, 1, 5, 5, 9, 1, 9, 9, -10, 0 };
const char vf_N[]  = { 1, 9, 1, 1, 9, 9, 9, 1, -10, 0 };
const char vf_O[]  = { 9, 3, 7, 1, 3, 1, 1, 3, 1, 7, 3, 9, 7, 9, 9, 7, 9, 3, -10, 0 };
const char vf_P[]  = { 1, 9, 1, 1, 7, 1, 9, 3, 7, 5, 1, 5, -10, 0 };
const char vf_Q[]  = { 9, 3, 7, 1, 3, 1, 1, 3, 1, 7, 3, 9, 7, 9, 9, 7, 9, 3, -2, 6, 6, 9, 9, -10, 0 };
const char vf_R[]  = { 1, 9, 1, 1, 7, 1, 9, 3, 7, 5, 1, 5, -2, 5, 5, 9, 9, -10, 0 };
const char vf_S[]  = { 9, 2, 7, 1, 3, 1, 1, 3, 3, 5, 7, 5, 9, 7, 7, 9, 3, 9, 1, 8, -10, 0 };
const char vf_T[]  = { 1, 1, 9, 1, -2, 5, 1, 5, 9, -10, 0 };
const char vf_U[]  = { 1, 1, 1, 7, 3, 9, 7, 9, 9, 7, 9, 1, -10, 0 };
const char vf_V[]  = { 1, 1, 5, 9, 9, 1, -10, 0 };
const char vf_W[]  = { 1, 1, 1, 9, 5, 5, 9, 9, 9, 1, -10, 0 };
const char vf_X[]  = { 1, 1, 9, 9, -2, 1, 9, 9, 1, -10, 0 };
const char vf_Y[]  = { 1, 1, 5, 5, 9, 1, -2, 5, 5, 5, 9, -10, 0 };
const char vf_Z[]  = { 1, 1, 9, 1, 1, 9, 9, 9, -10, 0 };

const char vf_lb[] = { 3, 0, 1, 0, 1, 10, 3, 10, -4, 0 };
const char vf_bs[] = { 1, 1, 5, 9, -6, 0 };
const char vf_rb[] = { 1, 0, 3, 0, 3, 10, 1, 10, -4, 0 };
const char vf_ca[] = { 1, 5, 5, 1, 9, 5, -10, 0 };
const char vf_us[] = { 1, 10, 9, 10, -10, 0 };
const char vf_bt[] = { 1, 1, 2, 3, -4, 0 };

const char vf_a[]  = { 7, 5, 7, 9, 3, 9, 1, 7, 3, 5, 7, 5, -8, 0 };
const char vf_b[]  = { 1, 1, 1, 9, 5, 9, 7, 7, 5, 5, 1, 5, -8, 0 };
const char vf_c[]  = { 7, 5, 3, 5, 1, 7, 3, 9, 7, 9, -8, 0 };
const char vf_d[]  = { 7, 1, 7, 9, 3, 9, 1, 7, 3, 5, 7, 5, -8, 0 };
const char vf_e[]  = { 1, 7, 7, 7, 5, 5, 3, 5, 1, 7, 3, 9, 7, 9, -8, 0 };
const char vf_f[]  = { 5, 1, 4, 1, 3, 2, 3, 9, -2, 1, 5, 5, 5, -6, 0 };
const char vf_g[]  = { 7, 9, 3, 9, 1, 7, 3, 5, 7, 5, 7, 12, 6, 13, 3, 13, -8, 0 };
const char vf_h[]  = { 1, 1, 1, 9, -2, 1, 5, 5, 5, 6, 6, 6, 9, -7, 0 };
const char vf_i[]  = { 2, 5, 2, 9, -2, 2, 3, 2, 3, -4, 0 };
const char vf_j[]  = { 3, 5, 3, 11, 1, 13, -2, 3, 3, 3, 3, -5, 0 };
const char vf_k[]  = { 1, 1, 1, 9, -2, 6, 5, 1, 7, 6, 9, -7, 0 };
const char vf_l[]  = { 2, 1, 2, 9, -4, 0 };
const char vf_m[]  = { 1, 9, 1, 5, 6, 5, 7, 6, 7, 9, -2, 4, 5, 4, 9, -8, 0 };
const char vf_n[]  = { 1, 9, 1, 5, 5, 5, 6, 6, 6, 9, -7, 0 };
const char vf_o[]  = { 7, 7, 5, 5, 3, 5, 1, 7, 3, 9, 5, 9, 7, 7, -8, 0 };
const char vf_p[]  = { 1, 9, 5, 9, 7, 7, 5, 5, 1, 5, 1, 13, -8, 0 };
const char vf_q[]  = { 7, 9, 3, 9, 1, 7, 3, 5, 7, 5, 7, 13, -8, 0  };
const char vf_r[]  = { 1, 9, 1, 5, -2, 1, 7, 3, 5, 5, 5, -6, 0 };
const char vf_s[]  = { 1, 9, 5, 9, 7, 8, 1, 6, 3, 5, 7, 5, -8, 0 };
const char vf_t[]  = { 3, 1, 3, 9, -2, 1, 4, 5, 4, -6, 0 };
const char vf_u[]  = { 1, 5, 1, 8, 3, 9, 5, 9, 7, 8, 7, 5, -8, 0 };
const char vf_v[]  = { 1, 5, 4, 9, 7, 5, -8, 0 };
const char vf_w[]  = { 1, 5, 1, 9, 4, 7, 7, 9, 7, 5, -8, 0 };
const char vf_x[]  = { 1, 5, 7, 9, -2, 1, 9, 7, 5, -8, 0 };
const char vf_y[]  = { 1, 5, 4, 9, -2, 7, 5, 1, 13, -8, 0 };
const char vf_z[]  = { 1, 5, 7, 5, 1, 9, 7, 9, -8, 0 };

const char vf_lr[] = { 3, 0, 2, 1, 2, 4, 1, 5, 2, 6, 2, 9, 3, 10, -4, 0 };
const char vf_pi[] = { 2, 1, 2, 9, -4, 0 };
const char vf_rr[] = { 1, 0, 2, 1, 2, 4, 3, 5, 2, 6, 2, 9, 1, 10, -4, 0 };
const char vf_ti[] = { 1, 3, 3, 1, 7, 3, 9, 1, -10, 0 };

const char* vf_ASCII[] = {
	0,     0,     0,     0,     0,     0,     0,     0,     0,     0,     vf_nl, 0,     0,     0,     0,     0,
	0,     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
	vf_sp, vf_ex, vf_qd, vf_ha, vf_do, vf_pr, vf_am, vf_qs,	vf_lp, vf_rp, vf_st, vf_pl, vf_cm, vf_mi, vf_pe, vf_fs,
	vf_0,  vf_1,  vf_2,  vf_3,  vf_4,  vf_5,  vf_6,  vf_7,  vf_8,  vf_9,  vf_co, vf_sc, vf_lt, vf_eq, vf_gt, vf_qu,
	vf_at, vf_A,  vf_B,  vf_C,  vf_D,  vf_E,  vf_F,  vf_G,  vf_H,  vf_I,  vf_J,  vf_K,  vf_L,  vf_M,  vf_N,  vf_O,
	vf_P,  vf_Q,  vf_R,  vf_S,  vf_T,  vf_U,  vf_V,  vf_W,  vf_X,  vf_Y,  vf_Z,  vf_lb, vf_bs, vf_rb, vf_ca, vf_us,
	vf_bt, vf_a,  vf_b,  vf_c,  vf_d,  vf_e,  vf_f,  vf_g,  vf_h,  vf_i,  vf_j,  vf_k,  vf_l,  vf_m,  vf_n,  vf_o,
	vf_p,  vf_q,  vf_r,  vf_s,  vf_t,  vf_u,  vf_v,  vf_w,  vf_x,  vf_y,  vf_z,  vf_lr, vf_pi, vf_rr, vf_ti, 0,
};

