#include <stdio.h>
#include <iostream.h>


//use SDL to include the correct OpenGL files for each platform
#include "SDL_OpenGL.h"
#include "SDL.h"
#include "SDL_mixer.h"
#include "RNG.h"
#include "sb_global.h"
#include "sb_MusicBox.h"
#include "sb_Noisemaker.h"
#include "sb_ShieldGrid.h"
#include "sb_ShieldSection.h"
#include "sb_Game.h"
#include "sb_GamePhase.h"
#include "sb_Phase_Title.h"
#include "sb_Phase_PlaceShields.h"
#include "sb_Phase_SetStage.h"
#include "sb_Phase_PlaceGuns.h"
#include "sb_Phase_Battle.h"
#include "sb_Phase_NewWave.h"
#include "sb_Phase_GameOver.h"

//screen definition
Uint16 screenWidth = 1024;
Uint16 screenHeight = 768;
Uint8  video_bpp = 0; //0 means to use whatever bit depth is already set by OS

void setUpSDL();
void setUpOpenGL();
void Quit( int returnCode );

int main(int argc, char *argv[])
{	
	//*setup video
	setUpSDL();
	setUpOpenGL();

    //*Pre game loop initialization BEGIN
	SDL_Event event;  //will hold events as they are polled
	int done; //set to true to end main loop

    SDL_ShowCursor(0); //hide the standard mouse pointer
    SDL_EnableKeyRepeat(0, SDL_DEFAULT_REPEAT_INTERVAL); //delay 0 means Disable Key Repeat
	
	sb_Game game; //game has gamewide variables including data objects (like musicBox and noisemaker)
	
	//The game Phases control all the mechanics in the game and how the game is displayed.
	sb_Phase_Title phase_Title(&game);
	sb_Phase_SetStage phase_SetStage( &game );
	sb_Phase_PlaceShields phase_PlaceShields( &game ); //each phase needs to have a pointer to the game object so it can access all the data
	sb_Phase_PlaceGuns phase_PlaceGuns( &game );
	sb_Phase_Battle phase_Battle( &game );
	sb_Phase_NewWave phase_NewWave( &game );
	sb_Phase_GameOver phase_GameOver( &game );
	
	sb_GamePhasePtr currentPhase;
	currentPhase = &phase_Title;  //set the currentPhase by pointing to the phase object we want
	
	//variables the main game loop needs to maintain
    Sint32 pointerX, pointerY, pointerRelX, pointerRelY; //to track mouse movement
    int commandKeyIsPressed = false;

	pointerX = 0; //start mouse pointer off at 0,0 at start in case event doesn't update it
	pointerY = 0;
	
	//*Pre game loop initialization END
	
	currentPhase->reset();
	currentPhase->start();
	done = false;
	
    //*Main Game Loop BEGIN	
	while ( !done )
    {
		if (game.gameover)
		{
			game.gameover = false;
			currentPhase = &phase_GameOver;
			currentPhase->reset();
			currentPhase->start();
		}
		
		if (game.newStage)
		{
			game.newStage = false;
			currentPhase = &phase_SetStage;
			currentPhase->reset();
			currentPhase->start();
		}
		
		if (game.newWave)
		{
			game.newWave = false;
			currentPhase = &phase_NewWave;
			currentPhase->reset();
			currentPhase->start();
		}
		
		if (currentPhase->isDone())
		{
			if (currentPhase == &phase_Title)
			{
				currentPhase = &phase_SetStage;
			}
			else if (currentPhase == &phase_SetStage)
			{
				currentPhase = &phase_PlaceGuns;
			}
			else if (currentPhase == &phase_PlaceGuns )
			{
				currentPhase = &phase_Battle;
			}
			else if (currentPhase == &phase_Battle )
			{
				currentPhase = &phase_PlaceShields;
			}
			else if (currentPhase == &phase_PlaceShields)
			{
				currentPhase = &phase_NewWave;
			}
			else if (currentPhase == &phase_NewWave)
			{
				currentPhase = &phase_PlaceGuns;
			}
			else if (currentPhase == &phase_GameOver)
			{
				//reset all of the variables
				game.reset();
				currentPhase = &phase_Title;
			}
			//switch currentPhase to next in line
			currentPhase->reset();
			currentPhase->start();
		}
		
        //reset the relative movement to 0
        pointerRelX = 0;
        pointerRelY = 0;
		
		//anything that needs to be set before the event loop in game object is done here
		game.preEvent();
        
        //* Poll events BEGIN
        while ( SDL_PollEvent(&event) )
        {
			//each phase has it's own way of processing events
			game.processEvent( event ); //needs to be done to update the pointer (all phases rely on game's pointer coordinates)
			currentPhase->processEvent( event );
            
			switch (event.type)
            {
                case SDL_MOUSEMOTION:
                    pointerX = event.motion.x;
                    pointerY = event.motion.y;
                    pointerRelX = event.motion.xrel;
                    pointerRelY = event.motion.yrel;
                    break;
                case SDL_MOUSEBUTTONDOWN:
					if (event.button.button == SDL_BUTTON_LEFT)
					{
					}
					if (event.button.button == SDL_BUTTON_RIGHT)
					{
					}

                    break;
                case SDL_MOUSEBUTTONUP:
                    break;
                case SDL_KEYDOWN:
					if (event.key.keysym.mod & KMOD_CTRL || commandKeyIsPressed)
					{
						switch (event.key.keysym.sym)
						{
							case SDLK_q:
								done = 1;
								break;
							default:
								break;
						}
					}
					if (event.key.keysym.sym == SDLK_r )
					{
						currentPhase->reset();
						currentPhase->start();
					}
					//command/meta key isn't considered a modifier key, so we take care of it manually
					if (event.key.keysym.sym == SDLK_LMETA || event.key.keysym.sym == SDLK_RMETA)
					{
						commandKeyIsPressed = true;
					}
					//the alt/option key
					if (event.key.keysym.sym == SDLK_LALT || event.key.keysym.sym == SDLK_RALT)
					{
					}
                    break;
                case SDL_KEYUP:
                    if (event.key.keysym.sym == SDLK_LMETA || event.key.keysym.sym == SDLK_RMETA)
                    {
                        commandKeyIsPressed = false;
                    }
                    if (event.key.keysym.sym == SDLK_LALT || event.key.keysym.sym == SDLK_RALT)
                    {
                    }
                    if (event.key.keysym.sym == SDLK_SPACE)
                    {
                    }
                    break;
                case SDL_QUIT:
                    done = 1;
                    break;
                default:
                    break;
            }
        }
		//*Poll Events END
		
	    //*update animation and game mechanics
		//the phase mechanics are internally timed to determine how much change from update to update
		currentPhase->animate(); //each phase object has it's own animate function
        
	    //*update visuals
		//***may need to compensate for VERY SLOW framerates so it isn't drawn if it takes too long to get here
		glClear (GL_COLOR_BUFFER_BIT);// Clear Screen And Depth Buffer

		currentPhase->draw(); //each phase object has it's own draw function
	
		glAAFlush();       // Flush the glAA pipeline
		glFlush();		   // Flush The GL Rendering Pipeline
		
		SDL_GL_SwapBuffers( ); // Render it all to the screen
    }
    //*Main Game Loop END

    /* Clean up the SDL library */
    Quit(0);
    return(0);
}


/*  void setUpSDL()
	SDL is useful for cross platform video/audio/joystick/network code.
	Should work with linked libraries on Mac, Windows, Linux, etc.
	combined with OpenGL, we can have a completely portable app 
*/
void setUpSDL()
{
	const SDL_VideoInfo *videoInfo;
    SDL_SurfacePtr screen; //Pointer to the screen buffer
	
    Uint32 initFlags = SDL_INIT_VIDEO;
    initFlags |= SDL_INIT_AUDIO;
    //initFlags |= SDL_INIT_JOYSTICK;
	
    //flags for initializing using SDL_SetVideoMode
    Uint32 videoFlags = SDL_OPENGL;    // enable OpenGL in SDL
    videoFlags |= SDL_HWPALETTE;       // store palette in hardware
	videoFlags |= SDL_FULLSCREEN;      // start in fullscreen
										//BUG?? when not in fullscreen mouse Y coordinates returned in events are reversed!
	//videoFlags |= SDL_RESIZABLE;       // enable window resizing
	//videoFlags |= SDL_GL_DOUBLEBUFFER; // enable double buffering  **does nothing in OS X currently
	
    //* initialize SDL
    if ( SDL_Init( initFlags ) < 0 )
    {
        fprintf( stderr, "SDL_Init() failed: %s\n", SDL_GetError() );
        Quit(1);
    }
	
    //set window name, (and icon if not null)
    SDL_WM_SetCaption("SpaceBarrage", NULL);
	
    //store info about current video
    videoInfo = SDL_GetVideoInfo();
    
    if (!videoInfo)
    {
        fprintf( stderr, "SDL_GetVideoInfo() failed: %s \n", SDL_GetError());
        Quit(1);
    }

    // Sets up OpenGL double buffering *currently does nothing on Mac OS X
    //SDL_GL_SetAttribute( SDL_GL_DOUBLEBUFFER, 1 );
	
    // set bpp to whatever format screen is already in
    //video_bpp = videoInfo->vfmt->BitsPerPixel;
	
    screen = SDL_SetVideoMode(screenWidth, screenHeight, video_bpp, videoFlags);
	
    // Make sure there is a screen
    if (!screen)
    {
        fprintf(stderr,  "SDL_SetVideoMode() failed: %s\n", SDL_GetError());
        Quit(1);
    }
}

/*  void setUpOpenGL()
	Using OpenGL for 2D video applications is more complicated initially but the
	advantages are extreme:
	-Hardware acceleration available on all platforms
	-Scaling, Rotation, Transparency, Antialiasing in some cases for almost no performance cost.
	-capability to mix 2D with 3D imagery easily
	-Huge amount of online documentation, tutorials, and support available for free
*/
void setUpOpenGL()
{

	
	// gl init
	glDisable(GL_LIGHTING);
	glShadeModel(GL_SMOOTH);
	glEnable(GL_BLEND);
	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
	glEnable(GL_ALPHA_TEST);
	glAlphaFunc(GL_GREATER, 1/255.0);
	
	// texture init
	glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
	glEnable(GL_TEXTURE_2D);
	glMatrixMode(GL_TEXTURE);
	glLoadIdentity();
	glScalef(0.125/phf, 0.125/phf, 1.0);	// glAARG requires rectangle coordinate setup for textures (phf is defined in AAPrimitives.h)
	
	//use glAArg for Anti-aliased lines and points ***NOTE: This currently breaks portability
	glAAInit();
	
	glAAGenerateAATex(0.0f, 0, false); //crisp AA due to 0.0f falloff setting
	glAAGenerateAATex(0.5f, 1, false); //softer lines due to 0.5f falloff setting
	glAAGenerateAATex(1.0f, 2, false); //even softer
	//now, before we draw lines or points, we can "glBindTexture(GL_TEXTURE_2D, glAA_texture[ A ]);" 
	//where 'A' is 0,1, or 2 and it will use the different style of softness for the line
	
    // ***GL_VERTEX_ARRAY_RANGE_APPLE undeclared???
	//glAAEnable(GL_VERTEX_ARRAY_RANGE_APPLE);	// we want VAR acceleration
	
	glClearColor(0.0f, 0.0f, 0.0f, 1.0f); // Background color
	
    // Setup our viewport
    glViewport(0, 0, (GLint)screenWidth, (GLint)screenHeight);
	
    // change to the projection matrix and set viewing volume
	glMatrixMode(GL_PROJECTION);        // Select The Projection Matrix
	glLoadIdentity();			// Reset The Projection Matrix
	gluOrtho2D(0, screenWidth, screenHeight, 0); // Set Up An Orthographic projection using screen coord
												 //OpenGL INITIALIZATION CODE END
}

void Quit( int returnCode )
{
    // Application Is Finished
    
    // clean up the window
    SDL_Quit( );

    // and exit appropriately
    exit( returnCode );
}
